This list is closed, nobody may subscribe to it.
| 2001 |
Jan
|
Feb
|
Mar
|
Apr
|
May
|
Jun
|
Jul
(19) |
Aug
(4) |
Sep
(20) |
Oct
(42) |
Nov
(80) |
Dec
(19) |
|---|---|---|---|---|---|---|---|---|---|---|---|---|
| 2002 |
Jan
(29) |
Feb
(100) |
Mar
(297) |
Apr
(115) |
May
(66) |
Jun
(145) |
Jul
(139) |
Aug
(19) |
Sep
(45) |
Oct
(53) |
Nov
(46) |
Dec
(148) |
| 2003 |
Jan
(277) |
Feb
(91) |
Mar
(17) |
Apr
(20) |
May
(63) |
Jun
(786) |
Jul
(1737) |
Aug
(740) |
Sep
(635) |
Oct
(538) |
Nov
(345) |
Dec
(652) |
| 2004 |
Jan
(1101) |
Feb
(557) |
Mar
(460) |
Apr
(154) |
May
(366) |
Jun
(296) |
Jul
(457) |
Aug
(582) |
Sep
(682) |
Oct
(515) |
Nov
(482) |
Dec
(711) |
| 2005 |
Jan
(819) |
Feb
(215) |
Mar
(398) |
Apr
(183) |
May
(459) |
Jun
(226) |
Jul
(303) |
Aug
(509) |
Sep
(566) |
Oct
(766) |
Nov
(294) |
Dec
(149) |
| 2006 |
Jan
(330) |
Feb
(192) |
Mar
(155) |
Apr
(633) |
May
(207) |
Jun
(51) |
Jul
(197) |
Aug
(121) |
Sep
(18) |
Oct
(54) |
Nov
(159) |
Dec
(134) |
| 2007 |
Jan
(341) |
Feb
(179) |
Mar
(220) |
Apr
(221) |
May
(71) |
Jun
(194) |
Jul
(283) |
Aug
(872) |
Sep
(406) |
Oct
(154) |
Nov
(103) |
Dec
(118) |
| 2008 |
Jan
(82) |
Feb
(192) |
Mar
(232) |
Apr
(215) |
May
(248) |
Jun
(604) |
Jul
(305) |
Aug
(228) |
Sep
(188) |
Oct
(195) |
Nov
(129) |
Dec
(110) |
| 2009 |
Jan
(182) |
Feb
(120) |
Mar
(150) |
Apr
(195) |
May
(74) |
Jun
(190) |
Jul
(339) |
Aug
(212) |
Sep
(101) |
Oct
(6) |
Nov
(7) |
Dec
(15) |
| 2010 |
Jan
(49) |
Feb
(127) |
Mar
(100) |
Apr
(60) |
May
(165) |
Jun
(41) |
Jul
(9) |
Aug
(32) |
Sep
(40) |
Oct
|
Nov
(7) |
Dec
(9) |
| 2011 |
Jan
(8) |
Feb
(8) |
Mar
(1) |
Apr
(6) |
May
(389) |
Jun
(278) |
Jul
(65) |
Aug
(10) |
Sep
(23) |
Oct
(67) |
Nov
(22) |
Dec
(96) |
| 2012 |
Jan
(30) |
Feb
(33) |
Mar
(54) |
Apr
(32) |
May
(3) |
Jun
(16) |
Jul
(44) |
Aug
(8) |
Sep
(4) |
Oct
(3) |
Nov
(4) |
Dec
(25) |
| 2013 |
Jan
(72) |
Feb
(23) |
Mar
(53) |
Apr
(16) |
May
(51) |
Jun
(37) |
Jul
(2) |
Aug
(1) |
Sep
|
Oct
(1) |
Nov
|
Dec
|
| 2014 |
Jan
|
Feb
|
Mar
(1) |
Apr
|
May
|
Jun
|
Jul
|
Aug
|
Sep
|
Oct
|
Nov
(5) |
Dec
|
|
From: <bul...@us...> - 2013-06-15 19:05:42
|
Revision: 22810
http://sourceforge.net/p/bzflag/code/22810
Author: bullet_catcher
Date: 2013-06-15 19:05:39 +0000 (Sat, 15 Jun 2013)
Log Message:
-----------
Add -Wredundant-decls and -pedantic to the set of standard GCC flags.
Prune the list of possible future warnings and annotate with the approximate number of each.
Modified Paths:
--------------
trunk/bzflag/configure.ac
Modified: trunk/bzflag/configure.ac
===================================================================
--- trunk/bzflag/configure.ac 2013-06-15 18:57:51 UTC (rev 22809)
+++ trunk/bzflag/configure.ac 2013-06-15 19:05:39 UTC (rev 22810)
@@ -690,13 +690,13 @@
# than the FLAGS they set.
#
# the GCC version is known to be at least 4.3 because it has C++0x support
-# possible future warnings: -Wconversion -Wfloat-equal -Wpointer-arith -Wredundant-decls -Wwrite-strings
-FLAGS="-Wall -Wextra -Wcast-qual -Wshadow -Wundef"
+# possible future warnings: -Wconversion (1894) -Wfloat-equal (317)
+FLAGS="-Wall -Wextra -Wcast-qual -Wredundant-decls -Wshadow -Wundef -pedantic"
case $host_os in
linux*)
AC_DEFINE(HALF_RATE_AUDIO, 1, [Half rate Audio])
CONF_CFLAGS="$CONF_CFLAGS $FLAGS"
- CONF_CXXFLAGS="$CONF_CXXFLAGS $FLAGS -pedantic"
+ CONF_CXXFLAGS="$CONF_CXXFLAGS $FLAGS"
case $host_vendor in
pc)
if expr `$CC -dumpversion` \>= "3.4" > /dev/null ; then
@@ -741,12 +741,13 @@
if test "$GCC" = yes ; then
FLAGS="$FLAGS -Wno-unknown-pragmas" # *silently* ignore "#pragma ident"
CONF_CFLAGS="$CONF_CFLAGS $FLAGS"
- CONF_CXXFLAGS="$CONF_CXXFLAGS $FLAGS -pedantic"
+ CONF_CXXFLAGS="$CONF_CXXFLAGS $FLAGS"
fi
;;
macos|darwin*)
CONF_CFLAGS="$CONF_CFLAGS $FLAGS";
- CONF_CXXFLAGS="$CONF_CXXFLAGS $FLAGS -pedantic";;
+ CONF_CXXFLAGS="$CONF_CXXFLAGS $FLAGS"
+ ;;
irix)
FLAGS="-Wall";
if test x$host_cpu = xmips64; then
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <bul...@us...> - 2013-06-15 18:57:55
|
Revision: 22809
http://sourceforge.net/p/bzflag/code/22809
Author: bullet_catcher
Date: 2013-06-15 18:57:51 +0000 (Sat, 15 Jun 2013)
Log Message:
-----------
Use only the __DATE__ macro as the source of the software build date.
If there is a need for software snapshot info it would be better served by a revision number or similar.
Modified Paths:
--------------
trunk/bzflag/include/version.h
trunk/bzflag/src/date/buildDate.cxx
Modified: trunk/bzflag/include/version.h
===================================================================
--- trunk/bzflag/include/version.h 2013-06-14 20:12:41 UTC (rev 22808)
+++ trunk/bzflag/include/version.h 2013-06-15 18:57:51 UTC (rev 22809)
@@ -15,11 +15,6 @@
#ifndef __VERSION_H__
#define __VERSION_H__
-#ifndef BZ_BUILD_DATE
-extern int getBuildDate();
-#define BZ_BUILD_DATE getBuildDate()
-#endif
-
#ifndef BZ_CONFIG_DIR_VERSION
#define BZ_CONFIG_DIR_VERSION "2.4"
#endif
Modified: trunk/bzflag/src/date/buildDate.cxx
===================================================================
--- trunk/bzflag/src/date/buildDate.cxx 2013-06-14 20:12:41 UTC (rev 22808)
+++ trunk/bzflag/src/date/buildDate.cxx 2013-06-15 18:57:51 UTC (rev 22809)
@@ -11,6 +11,7 @@
*/
#include "common.h"
+#include "version.h"
/* system headers */
#include <sstream>
@@ -55,34 +56,12 @@
const char *bzfcopyright = "Copyright (c) 1993-2013 Tim Riker";
-
-//
-// Although the ./configure process will generate
-// -DBZ_BUILD_DATE for the build, here it's voided.
-//
-// Could someone explain the reason for the
-// inconvenience caused by the ./configure method? This
-// way is simple, touch the *.cxx to get a new time
-// stamp (no big recompiles). If this file is updated,
-// you are also forced to get a new timestamp.
-//
-// Using __DATE__ for all OSes is more consistent.
-//
-#undef BZ_BUILD_DATE
-
-
-#ifndef BZ_BUILD_DATE
-/* to get the version in the right format YYYYMMDD */
-/* yes this is horrible but it needs to be done to get it right */
-/* windows should pull from a resource */
-/* *nix gets this from the passed from my the Makefile */
-char buildDate[] = {__DATE__};
-
-int getBuildDate()
+static int getBuildDate()
{
int year = 1900, month = 0, day = 0;
char monthStr[512];
- sscanf(buildDate, "%s %d %d", monthStr, &day, &year);
+ // the __DATE__ macro looks like "Jun 15 2013" (*with* the quotes)
+ sscanf(__DATE__, "%s %d %d", monthStr, &day, &year);
// we want it not as a name but a number
if (strcmp(monthStr, "Jan") == 0)
@@ -112,9 +91,6 @@
return (year*10000) + (month*100)+ day;
}
-#endif
-// down here so above gets created
-#include "version.h"
const char* getProtocolVersion()
{
@@ -156,7 +132,7 @@
if (!appVersion.size()){
std::ostringstream appVersionStream;
// TODO add current platform, release, cpu, etc
- appVersionStream << getMajorMinorRevVersion() << "." << BZ_BUILD_DATE
+ appVersionStream << getMajorMinorRevVersion() << "." << getBuildDate()
<< "-" << BZ_BUILD_TYPE << "-" << BZ_BUILD_OS;
#ifdef HAVE_SDL
appVersionStream << "-SDL";
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <bul...@us...> - 2013-06-14 20:12:44
|
Revision: 22808
http://sourceforge.net/p/bzflag/code/22808
Author: bullet_catcher
Date: 2013-06-14 20:12:41 +0000 (Fri, 14 Jun 2013)
Log Message:
-----------
Rename bzsignal.c to bzsignal.cxx so it will be compiled with the C++ compiler the same as all of the other source code.
Modified Paths:
--------------
trunk/bzflag/MSVC/build/common.vcxproj
trunk/bzflag/Xcode/BZFlag.xcodeproj/project.pbxproj
trunk/bzflag/src/common/Makefile.am
Added Paths:
-----------
trunk/bzflag/src/common/bzsignal.cxx
Removed Paths:
-------------
trunk/bzflag/src/common/bzsignal.c
Modified: trunk/bzflag/MSVC/build/common.vcxproj
===================================================================
--- trunk/bzflag/MSVC/build/common.vcxproj 2013-06-11 06:12:24 UTC (rev 22807)
+++ trunk/bzflag/MSVC/build/common.vcxproj 2013-06-14 20:12:41 UTC (rev 22808)
@@ -236,7 +236,7 @@
<ClCompile Include="..\..\src\common\bzfio.cxx" />
<ClCompile Include="..\..\src\common\bzglob.cxx" />
<ClCompile Include="..\..\src\common\BzPNG.cxx" />
- <ClCompile Include="..\..\src\common\bzsignal.c">
+ <ClCompile Include="..\..\src\common\bzsignal.cxx">
<Optimization Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">Disabled</Optimization>
<AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
<PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
Modified: trunk/bzflag/Xcode/BZFlag.xcodeproj/project.pbxproj
===================================================================
--- trunk/bzflag/Xcode/BZFlag.xcodeproj/project.pbxproj 2013-06-11 06:12:24 UTC (rev 22807)
+++ trunk/bzflag/Xcode/BZFlag.xcodeproj/project.pbxproj 2013-06-14 20:12:41 UTC (rev 22808)
@@ -203,7 +203,7 @@
0357A7C71670AFE30056C938 /* bzfio.cxx in Sources */ = {isa = PBXBuildFile; fileRef = 03554447166C846F008806E9 /* bzfio.cxx */; };
0357A7C81670AFE30056C938 /* bzglob.cxx in Sources */ = {isa = PBXBuildFile; fileRef = 03554448166C846F008806E9 /* bzglob.cxx */; };
0357A7C91670AFE30056C938 /* BzPNG.cxx in Sources */ = {isa = PBXBuildFile; fileRef = 03554449166C846F008806E9 /* BzPNG.cxx */; };
- 0357A7CA1670AFE30056C938 /* bzsignal.c in Sources */ = {isa = PBXBuildFile; fileRef = 0355444A166C846F008806E9 /* bzsignal.c */; };
+ 0357A7CA1670AFE30056C938 /* bzsignal.cxx in Sources */ = {isa = PBXBuildFile; fileRef = 0355444A166C846F008806E9 /* bzsignal.cxx */; };
0357A7CB1670AFE30056C938 /* CommandManager.cxx in Sources */ = {isa = PBXBuildFile; fileRef = 0355444B166C846F008806E9 /* CommandManager.cxx */; };
0357A7CC1670AFE30056C938 /* ConfigFileManager.cxx in Sources */ = {isa = PBXBuildFile; fileRef = 0355444C166C846F008806E9 /* ConfigFileManager.cxx */; };
0357A7CD1670AFE30056C938 /* Country.cxx in Sources */ = {isa = PBXBuildFile; fileRef = 0355444D166C846F008806E9 /* Country.cxx */; };
@@ -1708,7 +1708,7 @@
03554447166C846F008806E9 /* bzfio.cxx */ = {isa = PBXFileReference; lastKnownFileType = sourcecode.cpp.cpp; path = bzfio.cxx; sourceTree = "<group>"; };
03554448166C846F008806E9 /* bzglob.cxx */ = {isa = PBXFileReference; lastKnownFileType = sourcecode.cpp.cpp; path = bzglob.cxx; sourceTree = "<group>"; };
03554449166C846F008806E9 /* BzPNG.cxx */ = {isa = PBXFileReference; lastKnownFileType = sourcecode.cpp.cpp; path = BzPNG.cxx; sourceTree = "<group>"; };
- 0355444A166C846F008806E9 /* bzsignal.c */ = {isa = PBXFileReference; lastKnownFileType = sourcecode.c.c; path = bzsignal.c; sourceTree = "<group>"; };
+ 0355444A166C846F008806E9 /* bzsignal.cxx */ = {isa = PBXFileReference; lastKnownFileType = sourcecode.cpp.cpp; path = bzsignal.cxx; sourceTree = "<group>"; };
0355444B166C846F008806E9 /* CommandManager.cxx */ = {isa = PBXFileReference; lastKnownFileType = sourcecode.cpp.cpp; path = CommandManager.cxx; sourceTree = "<group>"; };
0355444C166C846F008806E9 /* ConfigFileManager.cxx */ = {isa = PBXFileReference; lastKnownFileType = sourcecode.cpp.cpp; path = ConfigFileManager.cxx; sourceTree = "<group>"; };
0355444D166C846F008806E9 /* Country.cxx */ = {isa = PBXFileReference; lastKnownFileType = sourcecode.cpp.cpp; path = Country.cxx; sourceTree = "<group>"; };
@@ -3218,7 +3218,7 @@
03554447166C846F008806E9 /* bzfio.cxx */,
03554448166C846F008806E9 /* bzglob.cxx */,
03554449166C846F008806E9 /* BzPNG.cxx */,
- 0355444A166C846F008806E9 /* bzsignal.c */,
+ 0355444A166C846F008806E9 /* bzsignal.cxx */,
0355444B166C846F008806E9 /* CommandManager.cxx */,
0355444C166C846F008806E9 /* ConfigFileManager.cxx */,
0355444D166C846F008806E9 /* Country.cxx */,
@@ -5611,7 +5611,7 @@
0357A7C71670AFE30056C938 /* bzfio.cxx in Sources */,
0357A7C81670AFE30056C938 /* bzglob.cxx in Sources */,
0357A7C91670AFE30056C938 /* BzPNG.cxx in Sources */,
- 0357A7CA1670AFE30056C938 /* bzsignal.c in Sources */,
+ 0357A7CA1670AFE30056C938 /* bzsignal.cxx in Sources */,
0357A7CB1670AFE30056C938 /* CommandManager.cxx in Sources */,
0357A7CC1670AFE30056C938 /* ConfigFileManager.cxx in Sources */,
0357A7CD1670AFE30056C938 /* Country.cxx in Sources */,
Modified: trunk/bzflag/src/common/Makefile.am
===================================================================
--- trunk/bzflag/src/common/Makefile.am 2013-06-11 06:12:24 UTC (rev 22807)
+++ trunk/bzflag/src/common/Makefile.am 2013-06-14 20:12:41 UTC (rev 22808)
@@ -41,7 +41,7 @@
bz_Locale.cxx \
bzfio.cxx \
bzglob.cxx \
- bzsignal.c \
+ bzsignal.cxx \
cURLManager.cxx \
global.cxx \
md5.cxx \
Deleted: trunk/bzflag/src/common/bzsignal.c
===================================================================
--- trunk/bzflag/src/common/bzsignal.c 2013-06-11 06:12:24 UTC (rev 22807)
+++ trunk/bzflag/src/common/bzsignal.c 2013-06-14 20:12:41 UTC (rev 22808)
@@ -1,56 +0,0 @@
-/* bzflag
- * Copyright (c) 1993-2013 Tim Riker
- *
- * This package is free software; you can redistribute it and/or
- * modify it under the terms of the license found in the file
- * named COPYING that should have accompanied this file.
- *
- * THIS PACKAGE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
- * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
- * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
- */
-
-#include "bzsignal.h"
-
-/* Unix systems implemnt signal() differently */
-/* modified from "UNIX Network Programming" */
-SIG_PF bzSignal(int signo, SIG_PF func)
-{
-#ifdef _WIN32
- return signal(signo, func);
-#else /* _WIN32 */
- struct sigaction act, oact;
-
- act.sa_handler = func;
- sigemptyset(&act.sa_mask);
-#ifdef SA_NODEFER
- act.sa_flags = SA_NODEFER;
-#else
- act.sa_flags = 0;
-#endif
- if (signo == SIGALRM) {
-#ifdef SA_INTERRUPT
- /* SunOS 4.x */
- act.sa_flags |= SA_INTERRUPT;
-#endif
- } else {
-#ifdef SA_RESTART
- /* SVR4, 4.4BSD */
- act.sa_flags |= SA_RESTART;
-#endif
- }
- if (sigaction(signo, &act, &oact) < 0)
- return SIG_ERR;
- return oact.sa_handler;
-#endif /* _WIN32 */
-}
-
-/*
- * Local Variables: ***
- * mode:C ***
- * tab-width: 8 ***
- * c-basic-offset: 2 ***
- * indent-tabs-mode: t ***
- * End: ***
- * ex: shiftwidth=2 tabstop=8
- */
Copied: trunk/bzflag/src/common/bzsignal.cxx (from rev 22807, trunk/bzflag/src/common/bzsignal.c)
===================================================================
--- trunk/bzflag/src/common/bzsignal.cxx (rev 0)
+++ trunk/bzflag/src/common/bzsignal.cxx 2013-06-14 20:12:41 UTC (rev 22808)
@@ -0,0 +1,56 @@
+/* bzflag
+ * Copyright (c) 1993-2013 Tim Riker
+ *
+ * This package is free software; you can redistribute it and/or
+ * modify it under the terms of the license found in the file
+ * named COPYING that should have accompanied this file.
+ *
+ * THIS PACKAGE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
+ * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+ */
+
+#include "bzsignal.h"
+
+/* Unix systems implemnt signal() differently */
+/* modified from "UNIX Network Programming" */
+SIG_PF bzSignal(int signo, SIG_PF func)
+{
+#ifdef _WIN32
+ return signal(signo, func);
+#else /* _WIN32 */
+ struct sigaction act, oact;
+
+ act.sa_handler = func;
+ sigemptyset(&act.sa_mask);
+#ifdef SA_NODEFER
+ act.sa_flags = SA_NODEFER;
+#else
+ act.sa_flags = 0;
+#endif
+ if (signo == SIGALRM) {
+#ifdef SA_INTERRUPT
+ /* SunOS 4.x */
+ act.sa_flags |= SA_INTERRUPT;
+#endif
+ } else {
+#ifdef SA_RESTART
+ /* SVR4, 4.4BSD */
+ act.sa_flags |= SA_RESTART;
+#endif
+ }
+ if (sigaction(signo, &act, &oact) < 0)
+ return SIG_ERR;
+ return oact.sa_handler;
+#endif /* _WIN32 */
+}
+
+/*
+ * Local Variables: ***
+ * mode:C ***
+ * tab-width: 8 ***
+ * c-basic-offset: 2 ***
+ * indent-tabs-mode: t ***
+ * End: ***
+ * ex: shiftwidth=2 tabstop=8
+ */
Property changes on: trunk/bzflag/src/common/bzsignal.cxx
___________________________________________________________________
Added: svn:mime-type
## -0,0 +1 ##
+text/plain
\ No newline at end of property
Added: svn:eol-style
## -0,0 +1 ##
+native
\ No newline at end of property
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <bul...@us...> - 2013-06-11 06:12:25
|
Revision: 22807
http://sourceforge.net/p/bzflag/code/22807
Author: bullet_catcher
Date: 2013-06-11 06:12:24 +0000 (Tue, 11 Jun 2013)
Log Message:
-----------
Revert r22806 and add the appropriate -std= compiler option to user_CXXFLAGS so it will be present in debug mode.
Revision Links:
--------------
http://sourceforge.net/p/bzflag/code/22806
Modified Paths:
--------------
trunk/bzflag/configure.ac
Modified: trunk/bzflag/configure.ac
===================================================================
--- trunk/bzflag/configure.ac 2013-06-10 23:44:37 UTC (rev 22806)
+++ trunk/bzflag/configure.ac 2013-06-11 06:12:24 UTC (rev 22807)
@@ -214,9 +214,11 @@
AX_CXX_COMPILE_STDCXX_0X
if test "x$ax_cv_cxx_compile_cxx0x_native" != xyes; then
if test "x$ax_cv_cxx_compile_cxx0x_cxx" = xyes; then
- CONF_CXXFLAGS="$CONF_CXXFLAGS -std=c++0x"
+ CXXFLAGS="$CXXFLAGS -std=c++0x"
+ user_CXXFLAGS="$user_CXXFLAGS -std=c++0x" # for --enable-debug
elif test "x$ax_cv_cxx_compile_cxx0x_gxx" = xyes; then
- CONF_CXXFLAGS="$CONF_CXXFLAGS -std=gnu++0x"
+ CXXFLAGS="$CXXFLAGS -std=gnu++0x"
+ user_CXXFLAGS="$user_CXXFLAGS -std=gnu++0x" # for --enable-debug
else
AC_MSG_ERROR([A c++ compiler with C++0x support is required to build BZFlag])
fi
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <bla...@us...> - 2013-06-10 23:44:41
|
Revision: 22806
http://sourceforge.net/p/bzflag/code/22806
Author: blast007
Date: 2013-06-10 23:44:37 +0000 (Mon, 10 Jun 2013)
Log Message:
-----------
Use CONF_CXXFLAGS instead of CXXFLAGS to prevent the options from being overwritten when building in debug mode.
Modified Paths:
--------------
trunk/bzflag/configure.ac
Modified: trunk/bzflag/configure.ac
===================================================================
--- trunk/bzflag/configure.ac 2013-06-09 07:20:18 UTC (rev 22805)
+++ trunk/bzflag/configure.ac 2013-06-10 23:44:37 UTC (rev 22806)
@@ -214,9 +214,9 @@
AX_CXX_COMPILE_STDCXX_0X
if test "x$ax_cv_cxx_compile_cxx0x_native" != xyes; then
if test "x$ax_cv_cxx_compile_cxx0x_cxx" = xyes; then
- CXXFLAGS="$CXXFLAGS -std=c++0x"
+ CONF_CXXFLAGS="$CONF_CXXFLAGS -std=c++0x"
elif test "x$ax_cv_cxx_compile_cxx0x_gxx" = xyes; then
- CXXFLAGS="$CXXFLAGS -std=gnu++0x"
+ CONF_CXXFLAGS="$CONF_CXXFLAGS -std=gnu++0x"
else
AC_MSG_ERROR([A c++ compiler with C++0x support is required to build BZFlag])
fi
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <kon...@us...> - 2013-06-09 07:20:22
|
Revision: 22805
http://sourceforge.net/p/bzflag/code/22805
Author: kongr45gpen
Date: 2013-06-09 07:20:18 +0000 (Sun, 09 Jun 2013)
Log Message:
-----------
Remove the -passdb option and restore -passwd (accidentally removed in r22798) on the BZFS man file
Revision Links:
--------------
http://sourceforge.net/p/bzflag/code/22798
Modified Paths:
--------------
trunk/bzflag/man/bzfs.6.in
Modified: trunk/bzflag/man/bzfs.6.in
===================================================================
--- trunk/bzflag/man/bzfs.6.in 2013-06-09 05:34:47 UTC (rev 22804)
+++ trunk/bzflag/man/bzfs.6.in 2013-06-09 07:20:18 UTC (rev 22805)
@@ -340,8 +340,9 @@
\fB\-packetlosswarn \fIpercent\fR
Send warnings to players that have more more than \fIpercent\fR loss.
.TP
-\fB\-passdb \fIfile\fR
-Load passwords from file
+\fB\-passwd \fIpassword\fR
+Specify a server administrator password for use in remote administration
+such as /kick, /ban, /mute, etc.\& messages.
.TP
\fB\-pidfile \fIfilename\fR
Specify a file where the server will write its process ID so it may be used for
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <bul...@us...> - 2013-06-09 05:34:50
|
Revision: 22804
http://sourceforge.net/p/bzflag/code/22804
Author: bullet_catcher
Date: 2013-06-09 05:34:47 +0000 (Sun, 09 Jun 2013)
Log Message:
-----------
Remove unused default arguments from VotingArbiter constructor, which the LLVM compiler warns make "this constructor a default constructor."
Modified Paths:
--------------
trunk/bzflag/include/VotingArbiter.h
Modified: trunk/bzflag/include/VotingArbiter.h
===================================================================
--- trunk/bzflag/include/VotingArbiter.h 2013-06-09 05:01:02 UTC (rev 22803)
+++ trunk/bzflag/include/VotingArbiter.h 2013-06-09 05:34:47 UTC (rev 22804)
@@ -231,11 +231,11 @@
};
-inline VotingArbiter::VotingArbiter(unsigned short int voteTime=60,
- unsigned short int vetoTime=20,
- unsigned short int votesRequired=2,
- float votePercentage=50.1,
- unsigned short int voteRepeatTime=300)
+inline VotingArbiter::VotingArbiter(unsigned short int voteTime,
+ unsigned short int vetoTime,
+ unsigned short int votesRequired,
+ float votePercentage,
+ unsigned short int voteRepeatTime)
: _votingBooth(NULL),
_maxVotes(votesRequired+1),
_voteTime(voteTime),
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <bul...@us...> - 2013-06-09 05:01:05
|
Revision: 22803
http://sourceforge.net/p/bzflag/code/22803
Author: bullet_catcher
Date: 2013-06-09 05:01:02 +0000 (Sun, 09 Jun 2013)
Log Message:
-----------
Remove unimplemented and unused Occluder::doCullSceneNode() method.
Modified Paths:
--------------
trunk/bzflag/src/scene/Occluder.cxx
trunk/bzflag/src/scene/Occluder.h
Modified: trunk/bzflag/src/scene/Occluder.cxx
===================================================================
--- trunk/bzflag/src/scene/Occluder.cxx 2013-06-09 04:53:08 UTC (rev 22802)
+++ trunk/bzflag/src/scene/Occluder.cxx 2013-06-09 05:01:02 UTC (rev 22803)
@@ -316,14 +316,6 @@
}
-bool Occluder::doCullSceneNode(SceneNode* node)
-{
- // FIXME - not yet implemented
- node = node;
- return false;
-}
-
-
static bool makePlane (const float* p1, const float* p2, const float* pc,
float* r)
{
@@ -481,3 +473,11 @@
return;
}
+
+// Local Variables: ***
+// mode:C++ ***
+// tab-width: 8 ***
+// c-basic-offset: 2 ***
+// indent-tabs-mode: t ***
+// End: ***
+// ex: shiftwidth=2 tabstop=8
Modified: trunk/bzflag/src/scene/Occluder.h
===================================================================
--- trunk/bzflag/src/scene/Occluder.h 2013-06-09 04:53:08 UTC (rev 22802)
+++ trunk/bzflag/src/scene/Occluder.h 2013-06-09 05:01:02 UTC (rev 22803)
@@ -21,7 +21,6 @@
~Occluder();
bool makePlanes(const Frustum* frustum);
IntersectLevel doCullAxisBox(const Extents& exts);
- bool doCullSceneNode(SceneNode* node);
void addScore(unsigned int score);
void divScore();
int getScore() const;
@@ -112,4 +111,3 @@
// indent-tabs-mode: t ***
// End: ***
// ex: shiftwidth=2 tabstop=8
-
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <bul...@us...> - 2013-06-09 04:53:11
|
Revision: 22802
http://sourceforge.net/p/bzflag/code/22802
Author: bullet_catcher
Date: 2013-06-09 04:53:08 +0000 (Sun, 09 Jun 2013)
Log Message:
-----------
Remove unused class private variables revealed by the LLVM compiler's -Wunused-private-field option.
Modified Paths:
--------------
trunk/bzflag/include/TankSceneNode.h
trunk/bzflag/src/bzflag/FormatMenu.h
trunk/bzflag/src/bzflag/MainMenu.cxx
trunk/bzflag/src/bzflag/MainMenu.h
trunk/bzflag/src/bzflag/Plan.cxx
trunk/bzflag/src/bzflag/Plan.h
trunk/bzflag/src/bzflag/ScoreboardRenderer.cxx
trunk/bzflag/src/bzflag/ScoreboardRenderer.h
trunk/bzflag/src/bzflag/SegmentedShotStrategy.cxx
trunk/bzflag/src/bzflag/SegmentedShotStrategy.h
trunk/bzflag/src/bzflag/ServerCommandKey.cxx
trunk/bzflag/src/bzflag/ServerCommandKey.h
trunk/bzflag/src/bzflag/effectsRenderer.cxx
trunk/bzflag/src/bzfs/ListServerConnection.cxx
trunk/bzflag/src/bzfs/ListServerConnection.h
trunk/bzflag/src/geometry/TankSceneNode.cxx
trunk/bzflag/src/platform/SDLDisplay.cxx
trunk/bzflag/src/platform/SDLDisplay.h
Modified: trunk/bzflag/include/TankSceneNode.h
===================================================================
--- trunk/bzflag/include/TankSceneNode.h 2013-06-09 03:53:58 UTC (rev 22801)
+++ trunk/bzflag/include/TankSceneNode.h 2013-06-09 04:53:08 UTC (rev 22802)
@@ -200,14 +200,11 @@
float leftWheelOffset;
float rightWheelOffset;
bool useDimensions;
- bool useOverride;
bool onlyShadows;
bool transparent, sort;
- float spawnFraction;
float explodeFraction;
bool clip;
bool inTheCockpit;
- GLfloat colorOverride[4];
GLfloat color[4];
GLdouble clipPlane[4];
OpenGLGState gstate;
@@ -242,4 +239,3 @@
// indent-tabs-mode: t ***
// End: ***
// ex: shiftwidth=2 tabstop=8
-
Modified: trunk/bzflag/src/bzflag/FormatMenu.h
===================================================================
--- trunk/bzflag/src/bzflag/FormatMenu.h 2013-06-09 03:53:58 UTC (rev 22801)
+++ trunk/bzflag/src/bzflag/FormatMenu.h 2013-06-09 04:53:08 UTC (rev 22802)
@@ -61,7 +61,6 @@
private:
FormatMenuDefaultKey defaultKey;
int numFormats;
- float center;
HUDuiLabel* currentLabel;
HUDuiLabel* pageLabel;
Modified: trunk/bzflag/src/bzflag/MainMenu.cxx
===================================================================
--- trunk/bzflag/src/bzflag/MainMenu.cxx 2013-06-09 03:53:58 UTC (rev 22801)
+++ trunk/bzflag/src/bzflag/MainMenu.cxx 2013-06-09 04:53:08 UTC (rev 22802)
@@ -32,7 +32,7 @@
#include "HUDui.h"
MainMenu::MainMenu() : HUDDialog(),
- join(), login(), options(), help(), leave(), save(), quit(),
+ join(), options(), help(), leave(), save(), quit(),
joinMenu(NULL), optionsMenu(NULL), quitMenu(NULL)
{
}
@@ -207,4 +207,3 @@
// indent-tabs-mode: t ***
// End: ***
// ex: shiftwidth=2 tabstop=8
-
Modified: trunk/bzflag/src/bzflag/MainMenu.h
===================================================================
--- trunk/bzflag/src/bzflag/MainMenu.h 2013-06-09 03:53:58 UTC (rev 22801)
+++ trunk/bzflag/src/bzflag/MainMenu.h 2013-06-09 04:53:08 UTC (rev 22802)
@@ -42,7 +42,6 @@
HUDuiControl* createLabel(const char* string);
HUDuiControl* join;
- HUDuiControl* login;
HUDuiControl* options;
HUDuiControl* help;
HUDuiControl* leave;
Modified: trunk/bzflag/src/bzflag/Plan.cxx
===================================================================
--- trunk/bzflag/src/bzflag/Plan.cxx 2013-06-09 03:53:58 UTC (rev 22801)
+++ trunk/bzflag/src/bzflag/Plan.cxx 2013-06-09 04:53:08 UTC (rev 22802)
@@ -484,7 +484,7 @@
* HuntTeamFlagPlan
*/
-HuntTeamFlagPlan::HuntTeamFlagPlan() : Plan(300.0f), flagID()
+HuntTeamFlagPlan::HuntTeamFlagPlan() : Plan(300.0f)
{
}
@@ -527,3 +527,10 @@
return NULL;
}
+// Local Variables: ***
+// mode:C++ ***
+// tab-width: 8 ***
+// c-basic-offset: 2 ***
+// indent-tabs-mode: t ***
+// End: ***
+// ex: shiftwidth=2 tabstop=8
Modified: trunk/bzflag/src/bzflag/Plan.h
===================================================================
--- trunk/bzflag/src/bzflag/Plan.h 2013-06-09 03:53:58 UTC (rev 22801)
+++ trunk/bzflag/src/bzflag/Plan.h 2013-06-09 04:53:08 UTC (rev 22802)
@@ -156,8 +156,6 @@
virtual bool isValid();
virtual bool usesSubPlan();
virtual Plan *createSubPlan();
-private:
- int flagID;
};
class CaptureFlagPlan : public Plan
@@ -179,4 +177,3 @@
// indent-tabs-mode: t ***
// End: ***
// ex: shiftwidth=2 tabstop=8
-
Modified: trunk/bzflag/src/bzflag/ScoreboardRenderer.cxx
===================================================================
--- trunk/bzflag/src/bzflag/ScoreboardRenderer.cxx 2013-06-09 03:53:58 UTC (rev 22801)
+++ trunk/bzflag/src/bzflag/ScoreboardRenderer.cxx 2013-06-09 04:53:08 UTC (rev 22802)
@@ -63,7 +63,6 @@
winWidth (0.0),
winHeight(),
dim(false),
- huntIndicator(false),
huntPosition(0),
huntSelectEvent(false),
huntPositionEvent(0),
Modified: trunk/bzflag/src/bzflag/ScoreboardRenderer.h
===================================================================
--- trunk/bzflag/src/bzflag/ScoreboardRenderer.h 2013-06-09 03:53:58 UTC (rev 22801)
+++ trunk/bzflag/src/bzflag/ScoreboardRenderer.h 2013-06-09 04:53:08 UTC (rev 22802)
@@ -103,7 +103,6 @@
float winHeight;
bool dim;
- bool huntIndicator;
int huntPosition;
bool huntSelectEvent;
int huntPositionEvent;
Modified: trunk/bzflag/src/bzflag/SegmentedShotStrategy.cxx
===================================================================
--- trunk/bzflag/src/bzflag/SegmentedShotStrategy.cxx 2013-06-09 03:53:58 UTC (rev 22801)
+++ trunk/bzflag/src/bzflag/SegmentedShotStrategy.cxx 2013-06-09 04:53:08 UTC (rev 22802)
@@ -31,7 +31,7 @@
#include "playing.h"
SegmentedShotStrategy::SegmentedShotStrategy(ShotPath* _path, bool useSuperTexture, bool faint) :
- ShotStrategy(_path), bbox(), firstSegment()
+ ShotStrategy(_path), bbox()
{
// initialize times
prevTime = getPath().getStartTime();
Modified: trunk/bzflag/src/bzflag/SegmentedShotStrategy.h
===================================================================
--- trunk/bzflag/src/bzflag/SegmentedShotStrategy.h 2013-06-09 03:53:58 UTC (rev 22801)
+++ trunk/bzflag/src/bzflag/SegmentedShotStrategy.h 2013-06-09 04:53:08 UTC (rev 22802)
@@ -66,7 +66,6 @@
std::vector<ShotPathSegment> segments;
BoltSceneNode* boltSceneNode;
float bbox[2][3];
- int firstSegment;
};
class NormalShotStrategy : public SegmentedShotStrategy {
Modified: trunk/bzflag/src/bzflag/ServerCommandKey.cxx
===================================================================
--- trunk/bzflag/src/bzflag/ServerCommandKey.cxx 2013-06-09 03:53:58 UTC (rev 22801)
+++ trunk/bzflag/src/bzflag/ServerCommandKey.cxx 2013-06-09 04:53:08 UTC (rev 22802)
@@ -26,7 +26,7 @@
/* FIXME - note the important numModes and numNonAdminModes values inited here
* when new commands are added, the indices need to be adjusted here.
*/
-ServerCommandKey::ServerCommandKey(): mode(LagStats), startIndex(-1), numModes(35), numNonAdminModes(6)
+ServerCommandKey::ServerCommandKey(): mode(LagStats), numModes(35), numNonAdminModes(6)
{
return;
}
@@ -422,3 +422,11 @@
}
return keyPress(key);
}
+
+// Local Variables: ***
+// mode:C++ ***
+// tab-width: 8 ***
+// c-basic-offset: 2 ***
+// indent-tabs-mode: t ***
+// End: ***
+// ex: shiftwidth=2 tabstop=8
Modified: trunk/bzflag/src/bzflag/ServerCommandKey.h
===================================================================
--- trunk/bzflag/src/bzflag/ServerCommandKey.h 2013-06-09 03:53:58 UTC (rev 22801)
+++ trunk/bzflag/src/bzflag/ServerCommandKey.h 2013-06-09 04:53:08 UTC (rev 22802)
@@ -69,12 +69,9 @@
};
Mode mode;
- int startIndex;
const int numModes;
const int numNonAdminModes;
static const Mode nonAdminModes[6];
-
-
};
#endif
@@ -86,4 +83,3 @@
// indent-tabs-mode: t ***
// End: ***
// ex: shiftwidth=2 tabstop=8
-
Modified: trunk/bzflag/src/bzflag/effectsRenderer.cxx
===================================================================
--- trunk/bzflag/src/bzflag/effectsRenderer.cxx 2013-06-09 03:53:58 UTC (rev 22801)
+++ trunk/bzflag/src/bzflag/effectsRenderer.cxx 2013-06-09 04:53:08 UTC (rev 22802)
@@ -58,7 +58,6 @@
float maxZ;
float ringRange;
- float numRings;
};
class StdShotEffect : public BasicEffect
@@ -819,7 +818,7 @@
//******************RingSpawnEffect****************
-RingSpawnEffect::RingSpawnEffect(): ringRange(), numRings()
+RingSpawnEffect::RingSpawnEffect(): ringRange()
{
radius = 4.0f;
maxZ = 10.0f;
@@ -1879,4 +1878,3 @@
// indent-tabs-mode: t ***
// End: ***
// ex: shiftwidth=2 tabstop=8
-
Modified: trunk/bzflag/src/bzfs/ListServerConnection.cxx
===================================================================
--- trunk/bzflag/src/bzfs/ListServerConnection.cxx 2013-06-09 03:53:58 UTC (rev 22801)
+++ trunk/bzflag/src/bzfs/ListServerConnection.cxx 2013-06-09 04:53:08 UTC (rev 22802)
@@ -65,7 +65,7 @@
queueMessage(ListServerLink::ADD);
}
-ListServerLink::ListServerLink(): nextMessageType(), port(0), queuedRequest(0)
+ListServerLink::ListServerLink(): nextMessageType(), queuedRequest(0)
{
// does not create a usable link, so checks should be placed
// in all public member functions to ensure that nothing tries
Modified: trunk/bzflag/src/bzfs/ListServerConnection.h
===================================================================
--- trunk/bzflag/src/bzfs/ListServerConnection.h 2013-06-09 03:53:58 UTC (rev 22801)
+++ trunk/bzflag/src/bzfs/ListServerConnection.h 2013-06-09 04:53:08 UTC (rev 22802)
@@ -49,7 +49,6 @@
// list server information
Address address;
- int port;
std::string hostname;
std::string pathname;
Modified: trunk/bzflag/src/geometry/TankSceneNode.cxx
===================================================================
--- trunk/bzflag/src/geometry/TankSceneNode.cxx 2013-06-09 03:53:58 UTC (rev 22801)
+++ trunk/bzflag/src/geometry/TankSceneNode.cxx 2013-06-09 04:53:08 UTC (rev 22802)
@@ -47,10 +47,9 @@
TankSceneNode::TankSceneNode(const GLfloat pos[3], const GLfloat forward[3]) :
leftTreadOffset(0.0f), rightTreadOffset(0.0f),
leftWheelOffset(0.0f), rightWheelOffset(0.0f),
- useDimensions(false), useOverride(false),
- onlyShadows(false), clip(false),
- inTheCockpit(false), tankRenderNode(this), treadsRenderNode(this),
- shadowRenderNode(this),
+ useDimensions(false), onlyShadows(false),
+ clip(false), inTheCockpit(false), tankRenderNode(this),
+ treadsRenderNode(this), shadowRenderNode(this),
tankSize(TankGeometryEnums::Normal)
{
// setup style factors (BZDB isn't set up at global init time
Modified: trunk/bzflag/src/platform/SDLDisplay.cxx
===================================================================
--- trunk/bzflag/src/platform/SDLDisplay.cxx 2013-06-09 03:53:58 UTC (rev 22801)
+++ trunk/bzflag/src/platform/SDLDisplay.cxx 2013-06-09 04:53:08 UTC (rev 22802)
@@ -601,7 +601,7 @@
}
SDLWindow::SDLWindow(const SDLDisplay* _display, SDLVisual*)
- : BzfWindow(_display), x(-1), y(-1), hasGamma(true)
+ : BzfWindow(_display), hasGamma(true)
{
}
Modified: trunk/bzflag/src/platform/SDLDisplay.h
===================================================================
--- trunk/bzflag/src/platform/SDLDisplay.h 2013-06-09 03:53:58 UTC (rev 22801)
+++ trunk/bzflag/src/platform/SDLDisplay.h 2013-06-09 04:53:08 UTC (rev 22802)
@@ -102,8 +102,6 @@
void freeContext() {;};
bool create(void);
private:
- int x;
- int y;
bool hasGamma;
};
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <bul...@us...> - 2013-06-09 03:54:01
|
Revision: 22801
http://sourceforge.net/p/bzflag/code/22801
Author: bullet_catcher
Date: 2013-06-09 03:53:58 +0000 (Sun, 09 Jun 2013)
Log Message:
-----------
Change some local variable names so they do not conflict with class field names.
Eliminates warnings with LLVM compiler's -Wshadow option.
Modified Paths:
--------------
trunk/bzflag/include/BoltSceneNode.h
trunk/bzflag/include/MeshTransform.h
trunk/bzflag/src/game/MeshTransform.cxx
trunk/bzflag/src/geometry/BoltSceneNode.cxx
trunk/bzflag/src/geometry/FlagSceneNode.cxx
trunk/bzflag/src/geometry/LaserSceneNode.cxx
trunk/bzflag/src/geometry/MeshPolySceneNode.cxx
trunk/bzflag/src/geometry/TankSceneNode.cxx
Modified: trunk/bzflag/include/BoltSceneNode.h
===================================================================
--- trunk/bzflag/include/BoltSceneNode.h 2013-06-08 22:27:31 UTC (rev 22800)
+++ trunk/bzflag/include/BoltSceneNode.h 2013-06-09 03:53:58 UTC (rev 22801)
@@ -62,7 +62,7 @@
void renderGeoBolt();
void renderGeoGMBolt();
- void renderGeoPill( float radius, float length, int segments, float endRad = -1);
+ void renderGeoPill( float radius, float len, int segments, float endRad = -1);
private:
const BoltSceneNode* sceneNode;
Modified: trunk/bzflag/include/MeshTransform.h
===================================================================
--- trunk/bzflag/include/MeshTransform.h 2013-06-08 22:27:31 UTC (rev 22800)
+++ trunk/bzflag/include/MeshTransform.h 2013-06-09 03:53:58 UTC (rev 22801)
@@ -83,7 +83,7 @@
const float* getMatrix() const;
private:
- void processTransforms(const std::vector<TransformData>& transforms);
+ void processTransforms(const std::vector<TransformData>& tforms);
bool empty;
bool inverted;
@@ -153,4 +153,3 @@
// indent-tabs-mode: t ***
// End: ***
// ex: shiftwidth=2 tabstop=8
-
Modified: trunk/bzflag/src/game/MeshTransform.cxx
===================================================================
--- trunk/bzflag/src/game/MeshTransform.cxx 2013-06-08 22:27:31 UTC (rev 22800)
+++ trunk/bzflag/src/game/MeshTransform.cxx 2013-06-09 03:53:58 UTC (rev 22801)
@@ -303,10 +303,10 @@
void MeshTransform::Tool::processTransforms(
- const std::vector<TransformData>& transforms)
+ const std::vector<TransformData>& tforms)
{
- for (unsigned int i = 0; i < transforms.size(); i++) {
- const TransformData& transform = transforms[i];
+ for (unsigned int i = 0; i < tforms.size(); i++) {
+ const TransformData& transform = tforms[i];
switch (transform.type) {
case ShiftTransform: {
shift(vertexMatrix, transform.data);
@@ -741,4 +741,3 @@
// indent-tabs-mode: t ***
// End: ***
// ex: shiftwidth=2 tabstop=8
-
Modified: trunk/bzflag/src/geometry/BoltSceneNode.cxx
===================================================================
--- trunk/bzflag/src/geometry/BoltSceneNode.cxx 2013-06-08 22:27:31 UTC (rev 22800)
+++ trunk/bzflag/src/geometry/BoltSceneNode.cxx 2013-06-09 03:53:58 UTC (rev 22801)
@@ -494,7 +494,7 @@
}
-void BoltSceneNode::BoltRenderNode::renderGeoPill(float radius, float length,
+void BoltSceneNode::BoltRenderNode::renderGeoPill(float radius, float len,
int segments, float endRad)
{
glPushMatrix();
@@ -503,7 +503,7 @@
if (endRad >= 0)
assRadius = endRad;
- float lenMinusRads = length - (radius+assRadius);
+ float lenMinusRads = len - (radius+assRadius);
GLUquadric *q = gluNewQuadric();
if (assRadius > 0)
@@ -667,9 +667,9 @@
const float invLenPlusOne = 1.0f / (float)(shotLength + 1);
const float shiftScale = 90.0f / (150.0f + (float)shotLength);
- float size = sceneNode->size * startSize;
+ float Size = sceneNode->size * startSize;
float alpha = startAlpha;
- const float sizeStep = size * invLenPlusOne;
+ const float sizeStep = Size * invLenPlusOne;
const float alphaStep = alpha * invLenPlusOne;
fvec3 pos;
@@ -680,8 +680,8 @@
int uvCell = rand() % 16;
for (int i = 0; i < shotLength; i++) {
- size -= sizeStep;
- const float s = size * (0.65f + (1.0f * (float)bzfrand()));
+ Size -= sizeStep;
+ const float s = Size * (0.65f + (1.0f * (float)bzfrand()));
const float shift = s * shiftScale;
pos += (shift * dir);
@@ -830,4 +830,3 @@
// indent-tabs-mode: t ***
// End: ***
// ex: shiftwidth=2 tabstop=8
-
Modified: trunk/bzflag/src/geometry/FlagSceneNode.cxx
===================================================================
--- trunk/bzflag/src/geometry/FlagSceneNode.cxx 2013-06-08 22:27:31 UTC (rev 22800)
+++ trunk/bzflag/src/geometry/FlagSceneNode.cxx 2013-06-09 03:53:58 UTC (rev 22801)
@@ -407,15 +407,15 @@
{
float base = BZDBCache::flagPoleSize;
float poleWidth = BZDBCache::flagPoleWidth;
- const bool texturing = sceneNode->texturing;
- const bool billboard = sceneNode->billboard;
- const bool transparent = sceneNode->transparent;
+ const bool doing_texturing = sceneNode->texturing;
+ const bool is_billboard = sceneNode->billboard;
+ const bool is_transparent = sceneNode->transparent;
const GLfloat* sphere = sceneNode->getSphere();
myColor4fv(sceneNode->color);
- if (!BZDBCache::blend && (transparent || texturing)) {
+ if (!BZDBCache::blend && (is_transparent || doing_texturing)) {
myStipple(sceneNode->color[3]);
}
@@ -423,17 +423,17 @@
{
glTranslatef(sphere[0], sphere[1], sphere[2]);
- if (billboard && realFlag) {
+ if (is_billboard && realFlag) {
// the pole
glRotatef(sceneNode->angle + 180.0f, 0.0f, 0.0f, 1.0f);
- const float tilt = sceneNode->tilt;
- const float hscl = sceneNode->hscl;
- static GLfloat shear[16] = {hscl, 0.0f, tilt, 0.0f,
+ const float Tilt = sceneNode->tilt;
+ const float Hscl = sceneNode->hscl;
+ static GLfloat shear[16] = {Hscl, 0.0f, Tilt, 0.0f,
0.0f, 1.0f, 0.0f, 0.0f,
0.0f, 0.0f, 1.0f, 0.0f,
0.0f, 0.0f, 0.0f, 1.0f};
- shear[0] = hscl; // maintains the flag length
- shear[2] = tilt; // pulls the flag up or down
+ shear[0] = Hscl; // maintains the flag length
+ shear[2] = Tilt; // pulls the flag up or down
glPushMatrix();
glMultMatrixf(shear);
allWaves[waveReference].execute();
@@ -442,7 +442,7 @@
myColor4f(0.0f, 0.0f, 0.0f, sceneNode->color[3]);
- if (texturing) {
+ if (doing_texturing) {
glDisable(GL_TEXTURE_2D);
}
@@ -465,7 +465,7 @@
addTriangleCount(8);
}
else {
- if (billboard) {
+ if (is_billboard) {
RENDERER.getViewFrustum().executeBillboard();
allWaves[waveReference].execute();
addTriangleCount(triCount);
@@ -487,7 +487,7 @@
myColor4f(0.0f, 0.0f, 0.0f, sceneNode->color[3]);
- if (texturing) {
+ if (doing_texturing) {
glDisable(GL_TEXTURE_2D);
}
@@ -514,10 +514,10 @@
}
glPopMatrix();
- if (texturing) {
+ if (doing_texturing) {
glEnable(GL_TEXTURE_2D);
}
- if (!BZDBCache::blend && transparent) {
+ if (!BZDBCache::blend && is_transparent) {
myStipple(0.5f);
}
}
@@ -530,4 +530,3 @@
// indent-tabs-mode: t ***
// End: ***
// ex: shiftwidth=2 tabstop=8
-
Modified: trunk/bzflag/src/geometry/LaserSceneNode.cxx
===================================================================
--- trunk/bzflag/src/geometry/LaserSceneNode.cxx 2013-06-08 22:27:31 UTC (rev 22800)
+++ trunk/bzflag/src/geometry/LaserSceneNode.cxx 2013-06-09 03:53:58 UTC (rev 22801)
@@ -151,7 +151,7 @@
void LaserSceneNode::LaserRenderNode::renderGeoLaser()
{
- const float length = sceneNode->length;
+ const float len = sceneNode->length;
const GLfloat* sphere = sceneNode->getSphere();
glPushMatrix();
glTranslatef(sphere[0], sphere[1], sphere[2]);
@@ -163,28 +163,28 @@
GLUquadric *q = gluNewQuadric();
- fvec4 centerColor = sceneNode->centerColor;
- centerColor.a = 0.85f;
- fvec4 color = sceneNode->color;
- color.a = 0.125f;
+ fvec4 coreColor = sceneNode->centerColor;
+ coreColor.a = 0.85f;
+ fvec4 mainColor = sceneNode->color;
+ mainColor.a = 0.125f;
- myColor4fv(centerColor);
- gluCylinder(q, 0.0625f, 0.0625f, length, 10, 1);
+ myColor4fv(coreColor);
+ gluCylinder(q, 0.0625f, 0.0625f, len, 10, 1);
addTriangleCount(20);
- myColor4fv(color);
- gluCylinder(q, 0.1f, 0.1f, length, 16, 1);
+ myColor4fv(mainColor);
+ gluCylinder(q, 0.1f, 0.1f, len, 16, 1);
addTriangleCount(32);
- myColor4fv(color);
- gluCylinder(q, 0.2f, 0.2f, length, 24, 1);
+ myColor4fv(mainColor);
+ gluCylinder(q, 0.2f, 0.2f, len, 24, 1);
addTriangleCount(48);
- myColor4fv(color);
- gluCylinder(q, 0.4f, 0.4f, length, 32, 1);
+ myColor4fv(mainColor);
+ gluCylinder(q, 0.4f, 0.4f, len, 32, 1);
addTriangleCount(64);
- myColor4fv(color);
+ myColor4fv(mainColor);
if (sceneNode->first) {
gluSphere(q, 0.5f, 32, 32);
addTriangleCount(32 * 32 * 2);
@@ -202,7 +202,7 @@
void LaserSceneNode::LaserRenderNode::renderFlatLaser()
{
- const float length = sceneNode->length;
+ const float len = sceneNode->length;
const GLfloat *sphere = sceneNode->getSphere();
glPushMatrix();
glTranslatef(sphere[0], sphere[1], sphere[2]);
@@ -226,18 +226,18 @@
glTexCoord2f(0.0f, 0.0f);
glVertex3f( 0.0f, 0.0f, 1.0f);
glTexCoord2f(0.0f, 1.0f);
- glVertex3f(length, 0.0f, 1.0f);
+ glVertex3f( len, 0.0f, 1.0f);
glTexCoord2f(1.0f, 1.0f);
- glVertex3f(length, 0.0f, -1.0f);
+ glVertex3f( len, 0.0f, -1.0f);
glTexCoord2f(1.0f, 0.0f);
glVertex3f( 0.0f, 0.0f, -1.0f);
glTexCoord2f(0.0f, 0.0f);
glVertex3f( 0.0f, 1.0f, 0.0f);
glTexCoord2f(0.0f, 1.0f);
- glVertex3f(length, 1.0f, 0.0f);
+ glVertex3f( len, 1.0f, 0.0f);
glTexCoord2f(1.0f, 1.0f);
- glVertex3f(length, -1.0f, 0.0f);
+ glVertex3f( len, -1.0f, 0.0f);
glTexCoord2f(1.0f, 0.0f);
glVertex3f( 0.0f, -1.0f, 0.0f);
glEnd(); // 8 verts -> 4 tris
@@ -251,19 +251,19 @@
glBegin(GL_QUAD_STRIP);
{
glVertex3f( 0.0f, geom[0][0], geom[0][1]);
- glVertex3f(length, geom[0][0], geom[0][1]);
+ glVertex3f( len, geom[0][0], geom[0][1]);
glVertex3f( 0.0f, geom[1][0], geom[1][1]);
- glVertex3f(length, geom[1][0], geom[1][1]);
+ glVertex3f( len, geom[1][0], geom[1][1]);
glVertex3f( 0.0f, geom[2][0], geom[2][1]);
- glVertex3f(length, geom[2][0], geom[2][1]);
+ glVertex3f( len, geom[2][0], geom[2][1]);
glVertex3f( 0.0f, geom[3][0], geom[3][1]);
- glVertex3f(length, geom[3][0], geom[3][1]);
+ glVertex3f( len, geom[3][0], geom[3][1]);
glVertex3f( 0.0f, geom[4][0], geom[4][1]);
- glVertex3f(length, geom[4][0], geom[4][1]);
+ glVertex3f( len, geom[4][0], geom[4][1]);
glVertex3f( 0.0f, geom[5][0], geom[5][1]);
- glVertex3f(length, geom[5][0], geom[5][1]);
+ glVertex3f( len, geom[5][0], geom[5][1]);
glVertex3f( 0.0f, geom[0][0], geom[0][1]);
- glVertex3f(length, geom[0][0], geom[0][1]);
+ glVertex3f( len, geom[0][0], geom[0][1]);
}
glEnd(); // 14 verts -> 12 tris
@@ -273,7 +273,7 @@
glBegin(GL_LINES);
{
glVertex3f( 0.0f, 0.0f, 0.0f);
- glVertex3f(length, 0.0f, 0.0f);
+ glVertex3f( len, 0.0f, 0.0f);
}
glEnd(); // count 1 line as 1 tri
@@ -290,4 +290,3 @@
// indent-tabs-mode: t ***
// End: ***
// ex: shiftwidth=2 tabstop=8
-
Modified: trunk/bzflag/src/geometry/MeshPolySceneNode.cxx
===================================================================
--- trunk/bzflag/src/geometry/MeshPolySceneNode.cxx 2013-06-08 22:27:31 UTC (rev 22800)
+++ trunk/bzflag/src/geometry/MeshPolySceneNode.cxx 2013-06-09 03:53:58 UTC (rev 22801)
@@ -33,12 +33,12 @@
// MeshPolySceneNode::Geometry
//
-MeshPolySceneNode::Geometry::Geometry(MeshPolySceneNode* node,
+MeshPolySceneNode::Geometry::Geometry(MeshPolySceneNode* _node,
const GLfloat3Array& _vertices, const GLfloat3Array& _normals,
const GLfloat2Array& _texcoords, const GLfloat* _normal) :
vertices(_vertices), normals(_normals), texcoords(_texcoords)
{
- sceneNode = node;
+ sceneNode = _node;
normal = _normal;
style = 0;
return;
@@ -760,4 +760,3 @@
// indent-tabs-mode: t ***
// End: ***
// ex: shiftwidth=2 tabstop=8
-
Modified: trunk/bzflag/src/geometry/TankSceneNode.cxx
===================================================================
--- trunk/bzflag/configure.ac 2013-06-08 22:24:15 UTC (rev 22799)
+++ trunk/bzflag/configure.ac 2013-06-08 22:27:31 UTC (rev 22800)
@@ -735,7 +735,13 @@
CONF_CXXFLAGS="$CONF_CXXFLAGS -fsigned-char";;
solaris*)
AC_DEFINE(ETC_INET, [], [hosts is in /etc/inet/])
- AC_DEFINE(SUN_OGL_NO_VERTEX_MACROS, [], [Sun OpenGL No Macro Vertex]);;
+ AC_DEFINE(SUN_OGL_NO_VERTEX_MACROS, [], [Sun OpenGL No Macro Vertex])
+ if test "$GCC" = yes ; then
+ FLAGS="$FLAGS -Wno-unknown-pragmas" # *silently* ignore "#pragma ident"
+ CONF_CFLAGS="$CONF_CFLAGS $FLAGS"
+ CONF_CXXFLAGS="$CONF_CXXFLAGS $FLAGS -pedantic"
+ fi
+ ;;
macos|darwin*)
CONF_CFLAGS="$CONF_CFLAGS $FLAGS";
CONF_CXXFLAGS="$CONF_CXXFLAGS $FLAGS -pedantic";;
@@ -1130,10 +1136,8 @@
ac_configure_args="$ac_configure_args --enable-ares --disable-manual"
case $host_os in
solaris*)
- if test "$GCC" != yes; then
- # Solaris 10 SSL libraries are compatible only with gcc
- ac_configure_args="$ac_configure_args --without-ssl"
- fi
+ # Solaris 10 SSL libraries are incompatible at link time
+ ac_configure_args="$ac_configure_args --without-ssl"
;;
esac
fi
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <bul...@us...> - 2013-06-08 22:24:18
|
Revision: 22799
http://sourceforge.net/p/bzflag/code/22799
Author: bullet_catcher
Date: 2013-06-08 22:24:15 +0000 (Sat, 08 Jun 2013)
Log Message:
-----------
Remove configure check for unused std::wstring type.
Add check for std::shared_ptr type.
Include support for fallback to std::tr1::shared_ptr for Apple LLVM (command line) compiler.
Use the same set of compiler warnings for Linux and Mac OS X command line tools.
Do not use GCC's -fexpensive-optimizations flag with Apple LLVM compiler.
Modified Paths:
--------------
trunk/bzflag/Xcode/config.h
trunk/bzflag/configure.ac
trunk/bzflag/src/bzfs/ShotManager.h
Modified: trunk/bzflag/Xcode/config.h
===================================================================
--- trunk/bzflag/Xcode/config.h 2013-06-08 17:56:40 UTC (rev 22798)
+++ trunk/bzflag/Xcode/config.h 2013-06-08 22:24:15 UTC (rev 22799)
@@ -183,9 +183,6 @@
/* Define to 1 if you have a conforming std::min */
#define HAVE_STD__MIN 1
-/* Define to 1 if the system has the type `std::wstring'. */
-#define HAVE_STD__WSTRING 1
-
/* Define to 1 if you have the <strings.h> header file. */
#define HAVE_STRINGS_H 1
Modified: trunk/bzflag/configure.ac
===================================================================
--- trunk/bzflag/configure.ac 2013-06-08 17:56:40 UTC (rev 22798)
+++ trunk/bzflag/configure.ac 2013-06-08 22:24:15 UTC (rev 22799)
@@ -453,7 +453,13 @@
esac
AC_LANG(C++)
-AC_CHECK_TYPES([std::wstring],,,[#include <iostream>])
+AC_CHECK_TYPES([std::shared_ptr<int>],
+ [# BZFlag expects std::shared_ptr support by default],
+ [AC_CHECK_TYPES([[std::tr1::shared_ptr<int>]],
+ AC_DEFINE([[USE_TR1]], [[1]], [Define to 1 to use C++0X TR1]),
+ AC_MSG_ERROR([[The C++11 std::shared_ptr type is required to build BZFlag]]),
+ [[#include <tr1/memory>]])],
+ [#include <memory>])
ac_cv_search_glBegin=no
ac_cv_search_gluScaleImage=no
@@ -680,10 +686,13 @@
# FIXME: these checks below are not compiler characteristics other
# than the FLAGS they set.
+#
+# the GCC version is known to be at least 4.3 because it has C++0x support
+# possible future warnings: -Wconversion -Wfloat-equal -Wpointer-arith -Wredundant-decls -Wwrite-strings
+FLAGS="-Wall -Wextra -Wcast-qual -Wshadow -Wundef"
case $host_os in
linux*)
AC_DEFINE(HALF_RATE_AUDIO, 1, [Half rate Audio])
- FLAGS="-Wall -Wextra -Wcast-qual -Wshadow -Wundef" # -Wconversion -Wfloat-equal -Wpointer-arith -Wredundant-decls -Wwrite-strings
CONF_CFLAGS="$CONF_CFLAGS $FLAGS"
CONF_CXXFLAGS="$CONF_CXXFLAGS $FLAGS -pedantic"
case $host_vendor in
@@ -728,7 +737,6 @@
AC_DEFINE(ETC_INET, [], [hosts is in /etc/inet/])
AC_DEFINE(SUN_OGL_NO_VERTEX_MACROS, [], [Sun OpenGL No Macro Vertex]);;
macos|darwin*)
- FLAGS="-pipe -Wno-long-long -W -Wall -Wundef -Wno-import"
CONF_CFLAGS="$CONF_CFLAGS $FLAGS";
CONF_CXXFLAGS="$CONF_CXXFLAGS $FLAGS -pedantic";;
irix)
@@ -764,9 +772,16 @@
AC_DEFINE(DEBUG, 1, [Debugging enabled])
else
if test "$GCC" = yes ; then
- OPTIMIZE="-fexpensive-optimizations"
- CONF_CFLAGS="$CONF_CFLAGS $OPTIMIZE"
- CONF_CXXFLAGS="$CONF_CXXFLAGS $OPTIMIZE"
+ case "`$CC --version 2>&1`" in
+ *LLVM*)
+ # Apple LLVM falsely claims to be GCC
+ ;;
+ *)
+ OPTIMIZE="-fexpensive-optimizations"
+ CONF_CFLAGS="$CONF_CFLAGS $OPTIMIZE"
+ CONF_CXXFLAGS="$CONF_CXXFLAGS $OPTIMIZE"
+ ;;
+ esac
fi
AC_DEFINE(NDEBUG, 1, [Debugging disabled])
fi
Modified: trunk/bzflag/src/bzfs/ShotManager.h
===================================================================
--- trunk/bzflag/src/bzfs/ShotManager.h 2013-06-08 17:56:40 UTC (rev 22798)
+++ trunk/bzflag/src/bzfs/ShotManager.h 2013-06-08 22:24:15 UTC (rev 22799)
@@ -23,8 +23,15 @@
#include <string>
#include <vector>
#include <map>
+#ifdef USE_TR1
+#include <tr1/memory>
+#include <tr1/functional>
+#define shared_ptr tr1::shared_ptr
+#define function tr1::function
+#else
#include <memory>
#include <functional>
+#endif
/** a ShotManager is used track shots fired by players and the server
*/
@@ -99,6 +106,12 @@
typedef std::vector<std::shared_ptr<Shot>> ShotList;
typedef std::shared_ptr<std::function <void (Shot&)> > ShotEvent;
+#ifdef USE_TR1
+// limit the scope of possible side effects of these macro definitions
+#undef shared_ptr
+#undef function
+#endif
+
#define INVALID_SHOT_GUID 0
class Manager
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <kon...@us...> - 2013-06-08 17:56:44
|
Revision: 22798
http://sourceforge.net/p/bzflag/code/22798
Author: kongr45gpen
Date: 2013-06-08 17:56:40 +0000 (Sat, 08 Jun 2013)
Log Message:
-----------
Update information about Command Line Options on the BZFS man file
Modified Paths:
--------------
trunk/bzflag/man/bzfs.6.in
Modified: trunk/bzflag/man/bzfs.6.in
===================================================================
--- trunk/bzflag/man/bzfs.6.in 2013-06-08 16:53:16 UTC (rev 22797)
+++ trunk/bzflag/man/bzfs.6.in 2013-06-08 17:56:40 UTC (rev 22798)
@@ -38,6 +38,7 @@
[\fB\-filterChat\fR]
[\fB\-filterSimple\fR]
[\fB\-g\fR]
+[\fB\-gndtex \fR\fItexture\-name\fR]
[\fB\-groupdb \fIfile\fR]
[\fB\-h\fR]
[\fB\-handicap\fR]
@@ -50,6 +51,7 @@
[\fB\-lagannounce \fR\fImilliseconds\fR]
[\fB\-lagdrop \fIwarn\-count\fR]
[\fB\-lagwarn \fR\fImilliseconds\fR]
+[\fB\-loadplugin \fR\fIname\fR[\fI,options\fR]]
[\fB\-masterBanURL \fIURL\fR]
[\fB\-maxidle \fR\fIseconds\fR]
[\fB\-mp
@@ -58,12 +60,12 @@
[\fB\-ms \fIshots\fR]
[\fB\-mts \fR\fImax\-score\fR]
[\fB\-noMasterBanlist\fR]
+[\fB\-noradar\fR]
+[\fB\-noTeamKills\fR]
[\fB\-offa\fR]
-[\fB\-noTeamKills\fR]
[\fB\-p \fIport\fR]
[\fB\-packetlossdrop \fIwarn\-count\fR]
[\fB\-packetlosswarn \fR\fIpercent\fR]
-[\fB\-passdb \fIfile\fR]
[\fB\-passwd \fIpassword\fR]
[\fB\-pidfile \fIfilename\fR]
[\fB\-poll \fIvariable=value\fR]
@@ -86,6 +88,7 @@
[\fB\-sa\fR]
[\fB\-sb\fR]
[\fB\-set \fIname value\fR]
+[\fB\-setforced \fIname value\fR]
[\fB\-sl \fIid num\fR]
[\fB\-spamtime \fItime\fR]
[\fB\-spamwarn \fIwarnLimit\fR]
@@ -93,14 +96,15 @@
[\fB\-srvmsg \fImessage\fR]
[\fB\-st \fItime\fR]
[\fB\-sw \fIcount\fR]
+[\fB\-synclocation\fR]
[\fB\-synctime\fR]
[\fB\-t\fR]
[\fB\-tftimeout \fItime\-limit\fR]
[\fB\-time \fR{\fItime\-limit\fR | \fIending-time\fR}]
[\fB\-timemanual\fR]
[\fB\-tk\fR]
+[\fB\-tkannounce]
[\fB\-tkkr \fIpercent\fR]
-[\fB\-trackplayhistory\fR]
[\fB\-ts \fR[\fImicros\fR]]
[\fB\-UPnP\fR]
[\fB\-userdb \fIfile\fR]
@@ -234,6 +238,9 @@
.B \-g
Quit after serving one game.
.TP
+\fB\-gndtex \fItexture\-name\fR
+Specify the name of the ground texture.
+.TP
\fB\-groupdb \fIfile\fR
Load groups from file
.TP
@@ -276,6 +283,11 @@
\fB\-lagwarn \fImilliseconds\fR
Send warnings to players that lag more than \fImilliseconds\fR.
.TP
+\fB\-loadplugin \fR\fIname\fR[\fI,options\fR]
+Load the specified plugin. \fIname\fR can either be the name of
+the plugin, or a path to its library file. Optionally, you can
+provide any options the plugin requires.
+.TP
\fB\-masterBanURL \fIURL\fR
Specify alternate URLs for the master ban file to be pulled from.
This argument may be provided multiple times.
@@ -308,13 +320,16 @@
.B \-noMasterBanlist
Server will not attempt to load the master ban list from the internet.
.TP
+.B \-noradar
+Disable the use of the radar.
+.TP
+.B \-noTeamKills
+Players on the same team are immune to each other's shots. Rogue is excepted.
+.TP
.B \-offa
Enables the Open\-Free\-for\-All style game. This is a teamless mode, similar to
the classic deathmatch in other games.
.TP
-.B \-noTeamKills
-Players on the same team are immune to each other's shots. Rogue is excepted.
-.TP
\fB\-p \fIport\fR
Listen for game connections on \fIport\fR instead of the default port.
Use \fB\-help\fR to print the default port, or use \fB\-d\fR debug printing.
@@ -328,10 +343,6 @@
\fB\-passdb \fIfile\fR
Load passwords from file
.TP
-\fB\-passwd \fIpassword\fR
-Specify a server administrator password for use in remote administration
-such as /kick, /ban, /mute, etc.\& messages.
-.TP
\fB\-pidfile \fIfilename\fR
Specify a file where the server will write its process ID so it may be used for
remote administration.
@@ -451,8 +462,11 @@
Allow spawns on box buildings.
.TP
.B \-set \fIname value\fR
-Set BZDB variable \fIname\fR to \fIvalue\fR
+Set BZDB variable \fIname\fR to \fIvalue\fR.
.TP
+.B \-setforced \fIname value\fR
+Set BZDB variable \fIname\fR to \fIvalue\fR, even if the variable does not exist.
+.TP
\fB\-sl \fIid num\fR
Restrict flag \fIid\fR to \fInum\fR shots.
.TP
@@ -476,6 +490,9 @@
Bad flags are automatically dropped after \fIcount\fR wins. Capturing
a team flag does not count as a win.
.TP
+.B \-synclocation
+Forces all clients to use the same location (longitude and latitude).
+.TP
.B \-synctime
Forces all clients to use the same time of day. The current time is
determined by the server's clock. This disables the + and \- keys on
@@ -508,14 +525,13 @@
When using this option, he will just get a \-1 score penalty for the kill but
not be killed in game.
.TP
+.B \-tkannounce
+Announce teamkills to the admin channel.
+.TP
\fB\-tkkr \fIpercent\fR
Kicks players whose team killing to normal kill ratio is greater than
\fIpercent\fR [1\-100]. A start up grace period is given to players.
.TP
-.B \-trackplayhistory
-Has the server track players with good runs of kills and announces them.
-Also announces those players that stop the runs of good players.
-.TP
\fB\-ts \fR[\fImicros\fR]
Include timestamp information in DEBUG output \(em useful for logging.
If \fImicros\fR is specified, microseconds will be added to the timestamp.
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <kon...@us...> - 2013-06-08 16:53:19
|
Revision: 22797
http://sourceforge.net/p/bzflag/code/22797
Author: kongr45gpen
Date: 2013-06-08 16:53:16 +0000 (Sat, 08 Jun 2013)
Log Message:
-----------
Don't show handicap values for observers
Modified Paths:
--------------
trunk/bzflag/src/bzfs/commands.cxx
Modified: trunk/bzflag/src/bzfs/commands.cxx
===================================================================
--- trunk/bzflag/src/bzfs/commands.cxx 2013-06-06 17:10:43 UTC (rev 22796)
+++ trunk/bzflag/src/bzfs/commands.cxx 2013-06-08 16:53:16 UTC (rev 22797)
@@ -1851,7 +1851,7 @@
const float maxhandicap = std::max(1.0f, BZDB.eval(StateDatabase::BZDB_HANDICAPSCOREDIFF)); // prevent division by zero below
for (int i = 0; i < curMaxPlayers; i++) {
GameKeeper::Player *p = GameKeeper::Player::getPlayerByIndex(i);
- if (p != NULL) {
+ if (p != NULL && !p->player.isObserver()) {
char reply[MessageLen];
snprintf(reply, MessageLen, "%-16s : %2d%%", p->player.getCallSign(), int(100.0 * std::min((float)p->score.getHandicap(), maxhandicap) / maxhandicap + 0.5));
sendMessage(ServerPlayer, t, reply);
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <kon...@us...> - 2013-06-06 17:10:47
|
Revision: 22796
http://sourceforge.net/p/bzflag/code/22796
Author: kongr45gpen
Date: 2013-06-06 17:10:43 +0000 (Thu, 06 Jun 2013)
Log Message:
-----------
Remove the /setpass command from the BZFS man file
Modified Paths:
--------------
trunk/bzflag/man/bzfs.6.in
Modified: trunk/bzflag/man/bzfs.6.in
===================================================================
--- trunk/bzflag/man/bzfs.6.in 2013-06-05 06:53:37 UTC (rev 22795)
+++ trunk/bzflag/man/bzfs.6.in 2013-06-06 17:10:43 UTC (rev 22796)
@@ -1314,10 +1314,6 @@
Add a user to a group
.TP
-.B /setpass \fIpassword\fR
-Changes your password
-
-.TP
.B /showgroup \fIcallsign\fR
Lists the groups that a registered user is a member of
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <bul...@us...> - 2013-06-05 06:53:39
|
Revision: 22795
http://sourceforge.net/p/bzflag/code/22795
Author: bullet_catcher
Date: 2013-06-05 06:53:37 +0000 (Wed, 05 Jun 2013)
Log Message:
-----------
Remove unused definition of PATH_MAX.
Modified Paths:
--------------
trunk/bzflag/include/win32.h
Modified: trunk/bzflag/include/win32.h
===================================================================
--- trunk/bzflag/include/win32.h 2013-06-05 06:50:59 UTC (rev 22794)
+++ trunk/bzflag/include/win32.h 2013-06-05 06:53:37 UTC (rev 22795)
@@ -70,8 +70,6 @@
// missing functions
# define snprintf _snprintf
-# define PATH_MAX MAX_PATH
-
namespace std {
template<typename _Tp>
int isnan(_Tp __f) { return _isnan((double)__f); }
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <bul...@us...> - 2013-06-05 06:51:02
|
Revision: 22794
http://sourceforge.net/p/bzflag/code/22794
Author: bullet_catcher
Date: 2013-06-05 06:50:59 +0000 (Wed, 05 Jun 2013)
Log Message:
-----------
Store the path to bzfs in a std::string instead of a fixed-length buffer.
Modified Paths:
--------------
trunk/bzflag/src/bzflag/ServerStartMenu.cxx
Modified: trunk/bzflag/src/bzflag/ServerStartMenu.cxx
===================================================================
--- trunk/bzflag/src/bzflag/ServerStartMenu.cxx 2013-06-03 18:10:04 UTC (rev 22793)
+++ trunk/bzflag/src/bzflag/ServerStartMenu.cxx 2013-06-05 06:50:59 UTC (rev 22794)
@@ -362,18 +362,15 @@
// other options as they were set
// get path to server from path to client
- // add 256 for flags room
- char serverCmd[PATH_MAX + 256];
- strcpy(serverCmd, argv0);
- char* base = strrchr(serverCmd, '/');
+ const char* base = strrchr(argv0, '/');
#if defined(_WIN32)
- char* base2 = strrchr(serverCmd, '\\');
- if (base2 && (!base || base2 - serverCmd > base - serverCmd))
+ const char* base2 = strrchr(argv0, '\\');
+ if (base2 && (!base || base2 - argv0 > base - argv0))
base = base2;
#endif
- if (!base) base = serverCmd;
+ if (!base) base = argv0;
else base++;
- strcpy(base, serverApp);
+ std::string serverCmd = TextUtils::format("%.*s%s", base-argv0, argv0, serverApp);
// prepare arguments for starting server
const char* args[30];
@@ -489,7 +486,7 @@
#if defined(_WIN32)
// Windows
- int result = _spawnvp(_P_DETACH, serverCmd, const_cast<char* const*>(args));
+ int result = _spawnvp(_P_DETACH, serverCmd.c_str(), const_cast<char* const*>(args));
if (result < 0) {
if (errno == ENOENT)
setStatus("Failed... can't find server program.");
@@ -498,8 +495,8 @@
else if (errno == ENOEXEC)
setStatus("Failed... server program is not executable.");
else
- setStatus(TextUtils::format("Failed... unknown error (%d).", errno, serverCmd).c_str());
- logDebugMessage(1,"Failed to start server (%s) - error %d.\n", serverCmd, errno);
+ setStatus(TextUtils::format("Failed... unknown error (%d).", errno).c_str());
+ logDebugMessage(1,"Failed to start server (%s) - error %d.\n", serverCmd.c_str(), errno);
}
else {
setStatus("Server started.");
@@ -541,7 +538,7 @@
close(2);
// exec server
- execvp(serverCmd, const_cast<char* const*>(args));
+ execvp(serverCmd.c_str(), const_cast<char* const*>(args));
// If execvp returns, bzfs wasnt at the anticipated location.
// Let execvp try to find it in $PATH by feeding it the "bzfs" name by it self
execvp(serverApp, const_cast<char* const*>(args));
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <bul...@us...> - 2013-06-03 18:10:07
|
Revision: 22793
http://sourceforge.net/p/bzflag/code/22793
Author: bullet_catcher
Date: 2013-06-03 18:10:04 +0000 (Mon, 03 Jun 2013)
Log Message:
-----------
Define MAXHOSTNAMELEN if it does not already exist.
Ensure host name buffer null termination regardless of gethostname() implementation details.
Modified Paths:
--------------
trunk/bzflag/include/network.h
trunk/bzflag/src/net/Address.cxx
Modified: trunk/bzflag/include/network.h
===================================================================
--- trunk/bzflag/include/network.h 2013-06-02 20:16:08 UTC (rev 22792)
+++ trunk/bzflag/include/network.h 2013-06-03 18:10:04 UTC (rev 22793)
@@ -93,8 +93,6 @@
#else /* !defined(_WIN32) */
-#define MAXHOSTNAMELEN 64
-
#ifndef EINPROGRESS
#define EINPROGRESS WSAEWOULDBLOCK
#endif
Modified: trunk/bzflag/src/net/Address.cxx
===================================================================
--- trunk/bzflag/src/net/Address.cxx 2013-06-02 20:16:08 UTC (rev 22792)
+++ trunk/bzflag/src/net/Address.cxx 2013-06-03 18:10:04 UTC (rev 22793)
@@ -37,6 +37,17 @@
extern "C" int inet_aton(const char *, struct in_addr *);
#endif
+// RFC 1035 limits the length of a fully qualified domain name to 255
+// octets, so calling sysconf(_SC_HOST_NAME_MAX) to find some other
+// limit and/or dynamically expanding the gethostname() buffer on
+// demand are complex solutions to a problem that does not exist in
+// the environments for which BZFlag is designed. The value chosen
+// here provides a substantial margin in case the RFC 1035 limit is
+// raised in the future.
+#ifndef MAXHOSTNAMELEN
+#define MAXHOSTNAMELEN 511
+#endif
+
//
// Address
//
@@ -136,10 +147,14 @@
if (name.length() > 0)
hent = gethostbyname(name.c_str());
else {
+ // use our own host name if none is specified
char hostname[MAXHOSTNAMELEN+1];
- if (gethostname(hostname, sizeof(hostname)) >= 0)
- // use our own host name if none is specified
+ if (gethostname(hostname, MAXHOSTNAMELEN) >= 0) {
+ // ensure null termination regardless of
+ // gethostname() implementation details
+ hostname[MAXHOSTNAMELEN] = '\0';
hent = gethostbyname(hostname);
+ }
}
return hent;
}
@@ -263,4 +278,3 @@
// indent-tabs-mode: t ***
// End: ***
// ex: shiftwidth=2 tabstop=8
-
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <bul...@us...> - 2013-06-02 20:16:10
|
Revision: 22792
http://sourceforge.net/p/bzflag/code/22792
Author: bullet_catcher
Date: 2013-06-02 20:16:08 +0000 (Sun, 02 Jun 2013)
Log Message:
-----------
Encapsulate two different calls to gethostname() into a new bz_gethostbyname() function.
Modified Paths:
--------------
trunk/bzflag/src/net/Address.cxx
Modified: trunk/bzflag/src/net/Address.cxx
===================================================================
--- trunk/bzflag/src/net/Address.cxx 2013-06-02 17:45:29 UTC (rev 22791)
+++ trunk/bzflag/src/net/Address.cxx 2013-06-02 20:16:08 UTC (rev 22792)
@@ -129,27 +129,34 @@
return 4;
}
+static const struct hostent* bz_gethostbyname(const std::string &name)
+{
+ const struct hostent* hent = NULL;
+
+ if (name.length() > 0)
+ hent = gethostbyname(name.c_str());
+ else {
+ char hostname[MAXHOSTNAMELEN+1];
+ if (gethostname(hostname, sizeof(hostname)) >= 0)
+ // use our own host name if none is specified
+ hent = gethostbyname(hostname);
+ }
+ return hent;
+}
+
Address Address::getHostAddress(const std::string &hname)
{
Address a;
InAddr tempAddr;
int j;
- struct hostent* hent;
- if (hname == "") { // local address
- char hostname[MAXHOSTNAMELEN+1];
- if (gethostname(hostname, sizeof(hostname)) >= 0)
- hent = gethostbyname(hostname);
- else
- return a;
- } else if (inet_aton(hname.c_str(), &tempAddr) != 0) {
+ if (hname.length() > 0 && inet_aton(hname.c_str(), &tempAddr) != 0) {
a.addr.clear();
a.addr.push_back(tempAddr);
return a;
- } else { // non-local address
- hent = gethostbyname(hname.c_str());
}
+ const struct hostent* hent = bz_gethostbyname(hname);
if (!hent) {
herror("Looking up host name");
return a;
@@ -177,16 +184,7 @@
const std::string Address::getHostName(const std::string &hostname) // const
{
- char myname[MAXHOSTNAMELEN+1];
- std::string name = hostname;
- if (name.length() <= 0) {
- if (gethostname(myname, sizeof(myname)) >= 0)
- name = std::string(myname);
- }
- if (name.length() <= 0) {
- return std::string();
- }
- struct hostent* hent = gethostbyname(name.c_str());
+ const struct hostent* hent = bz_gethostbyname(hostname);
if (!hent) {
return std::string();
}
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <bul...@us...> - 2013-06-02 17:45:33
|
Revision: 22791
http://sourceforge.net/p/bzflag/code/22791
Author: bullet_catcher
Date: 2013-06-02 17:45:29 +0000 (Sun, 02 Jun 2013)
Log Message:
-----------
Add "const" to the parameter of AresHandler::queryHost(), do what should be an unnecessary safety check that it isn't null, and remove the never-used call to gethostname().
Modified Paths:
--------------
trunk/bzflag/include/AresHandler.h
trunk/bzflag/src/net/AresHandler.cxx
Modified: trunk/bzflag/include/AresHandler.h
===================================================================
--- trunk/bzflag/include/AresHandler.h 2013-06-01 06:44:06 UTC (rev 22790)
+++ trunk/bzflag/include/AresHandler.h 2013-06-02 17:45:29 UTC (rev 22791)
@@ -43,7 +43,7 @@
void setIndex ( int i ) {index = i;}
void queryHostname(const struct sockaddr *clientAddr);
- void queryHost(char *hostName);
+ void queryHost(const char *hostName);
const char *getHostname();
ResolutionStatus getHostAddress(struct in_addr *clientAddr);
void setFd(fd_set *read_set, fd_set *write_set, int &maxFile);
Modified: trunk/bzflag/src/net/AresHandler.cxx
===================================================================
--- trunk/bzflag/src/net/AresHandler.cxx 2013-06-01 06:44:06 UTC (rev 22790)
+++ trunk/bzflag/src/net/AresHandler.cxx 2013-06-02 17:45:29 UTC (rev 22791)
@@ -91,32 +91,25 @@
logDebugMessage(2,"Player [%d] submitted reverse resolve query\n", index);
}
-void AresHandler::queryHost(char *hostName)
+void AresHandler::queryHost(const char *hostName)
{
if (aresFailed)
return;
ares_cancel(aresChannel);
+ if (!hostName) {
+ status = Failed;
+ return;
+ }
+
if (inet_aton(hostName, &hostAddress) != 0) {
status = HbNSucceeded;
return;
}
- char *queryHostName = hostName;
-
- char myHost[MAXHOSTNAMELEN+1];
- if (hostName == NULL || *hostName == '\0') {
- // local address
- if (gethostname(hostname, sizeof(hostname)) < 0) {
- status = Failed;
- return;
- }
- queryHostName = myHost;
- }
-
// launch the asynchronous query to look up this hostname
status = HbNPending;
- ares_gethostbyname(aresChannel, queryHostName, AF_INET, staticCallback,
+ ares_gethostbyname(aresChannel, hostName, AF_INET, staticCallback,
(void *)this);
}
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <bul...@us...> - 2013-06-01 06:44:08
|
Revision: 22790
http://sourceforge.net/p/bzflag/code/22790
Author: bullet_catcher
Date: 2013-06-01 06:44:06 +0000 (Sat, 01 Jun 2013)
Log Message:
-----------
Solaris 9 does not have ceilf(), so change the ListServerLink constructor to take a long, change ListServerReAddTime from float to double to better match the way it is used, and then good old ceil() is the correct function to use when calling the refactored constructor.
Modified Paths:
--------------
trunk/bzflag/Xcode/config.h
trunk/bzflag/configure.ac
trunk/bzflag/src/bzfs/ListServerConnection.cxx
trunk/bzflag/src/bzfs/ListServerConnection.h
trunk/bzflag/src/bzfs/bzfs.cxx
Modified: trunk/bzflag/Xcode/config.h
===================================================================
--- trunk/bzflag/Xcode/config.h 2013-05-31 06:45:17 UTC (rev 22789)
+++ trunk/bzflag/Xcode/config.h 2013-06-01 06:44:06 UTC (rev 22790)
@@ -62,9 +62,6 @@
/* Define to 1 if you have the `atexit' function. */
#define HAVE_ATEXIT 1
-/* libm includes ceilf */
-#define HAVE_CEILF 1
-
/* Define to 1 if you have the `CGLGetCurrentContext' function. */
#define HAVE_CGLGETCURRENTCONTEXT 1
Modified: trunk/bzflag/configure.ac
===================================================================
--- trunk/bzflag/configure.ac 2013-05-31 06:45:17 UTC (rev 22789)
+++ trunk/bzflag/configure.ac 2013-06-01 06:44:06 UTC (rev 22790)
@@ -310,7 +310,6 @@
AC_CHECK_LIB([m], [asinf], [AC_DEFINE([HAVE_ASINF],[1],[libm includes asinf])])
AC_CHECK_LIB([m], [atan2f], [AC_DEFINE([HAVE_ATAN2F],[1],[libm includes atan2f])])
AC_CHECK_LIB([m], [atanf], [AC_DEFINE([HAVE_ATANF],[1],[libm includes atanf])])
-AC_CHECK_LIB([m], [ceilf], [AC_DEFINE([HAVE_CEILF],[1],[libm includes ceilf])])
AC_CHECK_LIB([m], [cosf], [AC_DEFINE([HAVE_COSF],[1],[libm includes cosf])])
AC_CHECK_LIB([m], [expf], [AC_DEFINE([HAVE_EXPF],[1],[libm includes expf])])
AC_CHECK_LIB([m], [fabsf], [AC_DEFINE([HAVE_FABSF],[1],[libm includes fabsf])])
Modified: trunk/bzflag/src/bzfs/ListServerConnection.cxx
===================================================================
--- trunk/bzflag/src/bzfs/ListServerConnection.cxx 2013-05-31 06:45:17 UTC (rev 22789)
+++ trunk/bzflag/src/bzfs/ListServerConnection.cxx 2013-06-01 06:44:06 UTC (rev 22790)
@@ -18,7 +18,6 @@
/* system implementation headers */
#include <string.h>
#include <string>
-#include <math.h>
#include <errno.h>
#include <set>
@@ -39,7 +38,7 @@
std::string publicizedAddress,
std::string publicizedTitle,
std::string _advertiseGroups,
- float dnsCache)
+ long dnsCache)
{
std::string bzfsUserAgent = "bzfs ";
@@ -47,7 +46,7 @@
setURLwithNonce(listServerURL);
setUserAgent(bzfsUserAgent);
- setDNSCachingTime((long)ceilf(dnsCache));
+ setDNSCachingTime(dnsCache);
setTimeout(10);
publiclyDisconnected = false;
Modified: trunk/bzflag/src/bzfs/ListServerConnection.h
===================================================================
--- trunk/bzflag/src/bzfs/ListServerConnection.h 2013-05-31 06:45:17 UTC (rev 22789)
+++ trunk/bzflag/src/bzfs/ListServerConnection.h 2013-06-01 06:44:06 UTC (rev 22790)
@@ -32,7 +32,7 @@
// c'tor will fill list and local server information variables and
// do an initial ADD
ListServerLink(std::string listServerURL, std::string publicizedAddress,
- std::string publicizedTitle, std::string advertiseGroups, float dnsCache = 0);
+ std::string publicizedTitle, std::string advertiseGroups, long dnsCache = 0);
// c'tor with no arguments called when we don't want to use a list server.
ListServerLink();
// d'tor will REMOVE server and close connection
Modified: trunk/bzflag/src/bzfs/bzfs.cxx
===================================================================
--- trunk/bzflag/src/bzfs/bzfs.cxx 2013-05-31 06:45:17 UTC (rev 22789)
+++ trunk/bzflag/src/bzfs/bzfs.cxx 2013-06-01 06:44:06 UTC (rev 22790)
@@ -78,10 +78,10 @@
// pass through the SELECT loop
static bool dontWait = true;
-// every ListServerReAddTime server add ourself to the list
+// every ListServerReAddTime seconds add ourself to the list
// server again. this is in case the list server has reset
// or dropped us for some reason.
-static const float ListServerReAddTime = 15.0f * 60.0f;
+static const double ListServerReAddTime = 15 * 60;
static const float FlagHalfLife = 10.0f;
@@ -836,7 +836,8 @@
// list server initialization
for (std::vector<std::string>::const_iterator i = clOptions->listServerURL.begin(); i < clOptions->listServerURL.end(); ++i) {
listServerLink = new ListServerLink(i->c_str(),
- clOptions->publicizedAddress, clOptions->publicizedTitle, clOptions->advertiseGroups, ListServerReAddTime*2.0f); /* recheck dns every other re-add */
+ clOptions->publicizedAddress, clOptions->publicizedTitle, clOptions->advertiseGroups,
+ (long)ceil(ListServerReAddTime * 2)); /* recheck dns every other re-add */
listServerLinksCount++;
}
} else {
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <bul...@us...> - 2013-05-31 06:45:19
|
Revision: 22789
http://sourceforge.net/p/bzflag/code/22789
Author: bullet_catcher
Date: 2013-05-31 06:45:17 +0000 (Fri, 31 May 2013)
Log Message:
-----------
Do not assume that "g++" is the name of the c++ compiler.
Modified Paths:
--------------
trunk/bzflag/m4/ax_cxx_compile_stdcxx_0x.m4
Modified: trunk/bzflag/m4/ax_cxx_compile_stdcxx_0x.m4
===================================================================
--- trunk/bzflag/m4/ax_cxx_compile_stdcxx_0x.m4 2013-05-31 06:07:58 UTC (rev 22788)
+++ trunk/bzflag/m4/ax_cxx_compile_stdcxx_0x.m4 2013-05-31 06:45:17 UTC (rev 22789)
@@ -24,7 +24,7 @@
AU_ALIAS([AC_CXX_COMPILE_STDCXX_0X], [AX_CXX_COMPILE_STDCXX_0X])
AC_DEFUN([AX_CXX_COMPILE_STDCXX_0X], [
- AC_CACHE_CHECK(if g++ supports C++0x features without additional flags,
+ AC_CACHE_CHECK(if $CXX supports C++0x features without additional flags,
ax_cv_cxx_compile_cxx0x_native,
[AC_LANG_SAVE
AC_LANG_CPLUSPLUS
@@ -47,7 +47,7 @@
AC_LANG_RESTORE
])
- AC_CACHE_CHECK(if g++ supports C++0x features with -std=c++0x,
+ AC_CACHE_CHECK(if $CXX supports C++0x features with -std=c++0x,
ax_cv_cxx_compile_cxx0x_cxx,
[AC_LANG_SAVE
AC_LANG_CPLUSPLUS
@@ -73,7 +73,7 @@
AC_LANG_RESTORE
])
- AC_CACHE_CHECK(if g++ supports C++0x features with -std=gnu++0x,
+ AC_CACHE_CHECK(if $CXX supports C++0x features with -std=gnu++0x,
ax_cv_cxx_compile_cxx0x_gxx,
[AC_LANG_SAVE
AC_LANG_CPLUSPLUS
@@ -102,6 +102,6 @@
if test "$ax_cv_cxx_compile_cxx0x_native" = yes ||
test "$ax_cv_cxx_compile_cxx0x_cxx" = yes ||
test "$ax_cv_cxx_compile_cxx0x_gxx" = yes; then
- AC_DEFINE(HAVE_STDCXX_0X,,[Define if g++ supports C++0x features. ])
+ AC_DEFINE(HAVE_STDCXX_0X,,[Define if the c++ compiler supports C++0x features. ])
fi
])
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <bul...@us...> - 2013-05-31 06:08:02
|
Revision: 22788
http://sourceforge.net/p/bzflag/code/22788
Author: bullet_catcher
Date: 2013-05-31 06:07:58 +0000 (Fri, 31 May 2013)
Log Message:
-----------
Change local variable name from "quad" to "quadric" to avoid confusion with a Solaris typedef.
Modified Paths:
--------------
trunk/bzflag/src/geometry/SphereSceneNode.cxx
Modified: trunk/bzflag/src/geometry/SphereSceneNode.cxx
===================================================================
--- trunk/bzflag/src/geometry/SphereSceneNode.cxx 2013-05-31 04:48:45 UTC (rev 22787)
+++ trunk/bzflag/src/geometry/SphereSceneNode.cxx 2013-05-31 06:07:58 UTC (rev 22788)
@@ -126,20 +126,20 @@
{
GLuint list;
- GLUquadric* quad = gluNewQuadric();
- gluQuadricDrawStyle(quad, GLU_FILL);
- gluQuadricTexture(quad, GL_TRUE);
- gluQuadricNormals(quad, GL_SMOOTH);
- gluQuadricOrientation(quad, GLU_OUTSIDE);
+ GLUquadric* quadric = gluNewQuadric();
+ gluQuadricDrawStyle(quadric, GLU_FILL);
+ gluQuadricTexture(quadric, GL_TRUE);
+ gluQuadricNormals(quadric, GL_SMOOTH);
+ gluQuadricOrientation(quadric, GLU_OUTSIDE);
list = glGenLists(1);
glNewList(list, GL_COMPILE);
{
- gluSphere(quad, radius, slices, stacks);
+ gluSphere(quadric, radius, slices, stacks);
}
glEndList();
- gluDeleteQuadric(quad);
+ gluDeleteQuadric(quadric);
return list;
}
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <bul...@us...> - 2013-05-31 04:48:48
|
Revision: 22787
http://sourceforge.net/p/bzflag/code/22787
Author: bullet_catcher
Date: 2013-05-31 04:48:45 +0000 (Fri, 31 May 2013)
Log Message:
-----------
Preserve const quality in XDisplay::setupEvent().
Modified Paths:
--------------
trunk/bzflag/src/platform/XDisplay.cxx
Modified: trunk/bzflag/src/platform/XDisplay.cxx
===================================================================
--- trunk/bzflag/src/platform/XDisplay.cxx 2013-05-30 18:27:42 UTC (rev 22786)
+++ trunk/bzflag/src/platform/XDisplay.cxx 2013-05-31 04:48:45 UTC (rev 22787)
@@ -213,7 +213,7 @@
break;
case ClientMessage: {
- XClientMessageEvent* cme = (XClientMessageEvent*)&xevent;
+ const XClientMessageEvent* cme = (const XClientMessageEvent*)&xevent;
if (cme->format == 32) {
if ((Atom)cme->data.l[0] == XInternAtom(rep->getDisplay(),
"WM_DELETE_WINDOW", true)) {
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <bul...@us...> - 2013-05-30 18:27:45
|
Revision: 22786
http://sourceforge.net/p/bzflag/code/22786
Author: bullet_catcher
Date: 2013-05-30 18:27:42 +0000 (Thu, 30 May 2013)
Log Message:
-----------
Use a copy of an XKeyEvent structure to preserve its const quality.
Modified Paths:
--------------
trunk/bzflag/src/platform/XDisplay.cxx
Modified: trunk/bzflag/src/platform/XDisplay.cxx
===================================================================
--- trunk/bzflag/src/platform/XDisplay.cxx 2013-05-30 18:14:07 UTC (rev 22785)
+++ trunk/bzflag/src/platform/XDisplay.cxx 2013-05-30 18:27:42 UTC (rev 22786)
@@ -234,7 +234,8 @@
{
char buf[3];
KeySym keysym;
- if (XLookupString((XKeyEvent*)&xevent.xkey, buf, 1, &keysym, NULL) == 1) {
+ XKeyEvent xkey = xevent.xkey; // non-const copy
+ if (XLookupString(&xkey, buf, 1, &keysym, NULL) == 1) {
key.ascii = buf[0];
key.button = BzfKeyEvent::NoButton;
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
--- trunk/bzflag/src/geometry/TankSceneNode.cxx 2013-06-08 22:27:31 UTC (rev 22800)
+++ trunk/bzflag/src/geometry/TankSceneNode.cxx 2013-06-09 03:53:58 UTC (rev 22801)
@@ -735,19 +735,19 @@
const GLfloat azimuth = sceneNode->tank->azimuth;
const GLfloat ca = cosf(-azimuth * (float)M_PI / 180.0f);
const GLfloat sa = sinf(-azimuth * (float)M_PI / 180.0f);
- GLfloat plane[4];
- plane[0] = ca * _plane[0] - sa * _plane[1];
- plane[1] = sa * _plane[0] + ca * _plane[1];
- plane[2] = _plane[2];
- plane[3] = (sphere[0] * _plane[0] + sphere[1] * _plane[1] +
- sphere[2] * _plane[2] + _plane[3]);
+ GLfloat tankPlane[4];
+ tankPlane[0] = ca * _plane[0] - sa * _plane[1];
+ tankPlane[1] = sa * _plane[0] + ca * _plane[1];
+ tankPlane[2] = _plane[2];
+ tankPlane[3] = (sphere[0] * _plane[0] + sphere[1] * _plane[1] +
+ sphere[2] * _plane[2] + _plane[3]);
- // compute projection point -- one TankLength in from plane
- const GLfloat pd = -1.0f * BZDBCache::tankLength - plane[3];
+ // compute projection point -- one TankLength in from tankPlane
+ const GLfloat pd = -1.0f * BZDBCache::tankLength - tankPlane[3];
GLfloat origin[3];
- origin[0] = pd * plane[0];
- origin[1] = pd * plane[1];
- origin[2] = pd * plane[2];
+ origin[0] = pd * tankPlane[0];
+ origin[1] = pd * tankPlane[1];
+ origin[2] = pd * tankPlane[2];
glPushMatrix();
glTranslatef(sphere[0], sphere[1], sphere[2]);
@@ -756,16 +756,16 @@
glBegin(GL_QUADS);
const int numFaces = countof(idlFaces);
for (int i = 0; i < numFaces; i++) {
// get distances from plane
const int* face = idlFaces[i] + 1;
const int numVertices = idlFaces[i][0];
GLfloat d[4];
int j;
for (j = 0; j < numVertices; j++)
- d[j] = idlVertex[face[j]][0] * plane[0] +
- idlVertex[face[j]][1] * plane[1] +
- idlVertex[face[j]][2] * plane[2] +
- plane[3];
+ d[j] = idlVertex[face[j]][0] * tankPlane[0] +
+ idlVertex[face[j]][1] * tankPlane[1] +
+ idlVertex[face[j]][2] * tankPlane[2] +
+ tankPlane[3];
// get crossing points
GLfloat cross[2][3];
@@ -1202,12 +1202,12 @@
sceneNode->deathOverride->SetDeathRenderParams(params);
if (!overide)
{
- const float* vel = sceneNode->vel[part];
- const float* spin = sceneNode->spin[part];
- glTranslatef(cog[0] + (explodeFraction * vel[0]),
- cog[1] + (explodeFraction * vel[1]),
- cog[2] + (explodeFraction * vel[2]));
- glRotatef(spin[3] * explodeFraction, spin[0], spin[1], spin[2]);
+ const float* velocity = sceneNode->vel[part];
+ const float* rotation = sceneNode->spin[part];
+ glTranslatef(cog[0] + (explodeFraction * velocity[0]),
+ cog[1] + (explodeFraction * velocity[1]),
+ cog[2] + (explodeFraction * velocity[2]));
+ glRotatef(rotation[3] * explodeFraction, rotation[0], rotation[1], rotation[2]);
glTranslatef(-cog[0], -cog[1], -cog[2]);
}
else
@@ -1448,8 +1448,8 @@
myColor4f(1.0f, 1.0f, 1.0f, 0.5f);
// use a clip plane, because the ground has no depth
- const GLdouble clipPlane[4] = {0.0f, 0.0f, 1.0f, 0.0f};
- glClipPlane(GL_CLIP_PLANE1, clipPlane);
+ const GLdouble clip_plane[4] = {0.0f, 0.0f, 1.0f, 0.0f};
+ glClipPlane(GL_CLIP_PLANE1, clip_plane);
glEnable(GL_CLIP_PLANE1);
sceneNode->jumpJetsGState.setState();
@@ -1492,4 +1492,3 @@
// indent-tabs-mode: t ***
// End: ***
// ex: shiftwidth=2 tabstop=8
-
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <bul...@us...> - 2013-06-08 22:27:33
|
Revision: 22800
http://sourceforge.net/p/bzflag/code/22800
Author: bullet_catcher
Date: 2013-06-08 22:27:31 +0000 (Sat, 08 Jun 2013)
Log Message:
-----------
For Solaris, use -Wno-unknown-pragmas to silence useless warnings about system headers and always build cURL without SSL.
Modified Paths:
--------------
trunk/bzflag/configure.ac
Modified: trunk/bzflag/configure.ac
===================================================================
@@ -756,16 +756,16 @@
const int numFaces = countof(idlFaces);
for (int i = 0; i < numFaces; i++) {
- // get distances from plane
+ // get distances from tankPlane
const int* face = idlFaces[i] + 1;
const int numVertices = idlFaces[i][0];